"""
This file offers the methods to automatically retrieve the graph kg-microbe.

The graph is automatically retrieved from the KGHub repository. 



"""
from typing import Dict

from ..automatic_graph_retrieval import AutomaticallyRetrievedGraph
from ...ensmallen import Graph  # pylint: disable=import-error


def KGMicrobe(
    directed: bool = False,
    preprocess: bool = True,
    load_nodes: bool = True,
    verbose: int = 2,
    cache: bool = True,
    cache_path: str = "graphs/kghub",
    version: str = "current",
    **additional_graph_kwargs: Dict
) -> Graph:
    """Return new instance of the kg-microbe graph.

    The graph is automatically retrieved from the KGHub repository.	

    Parameters
    -------------------
    directed: bool = False
        Wether to load the graph as directed or undirected.
        By default false.
    preprocess: bool = True
        Whether to preprocess the graph to be loaded in 
        optimal time and memory.
    load_nodes: bool = True,
        Whether to load the nodes vocabulary or treat the nodes
        simply as a numeric range.
    verbose: int = 2,
        Wether to show loading bars during the retrieval and building
        of the graph.
    cache: bool = True
        Whether to use cache, i.e. download files only once
        and preprocess them only once.
    cache_path: str = "graphs"
        Where to store the downloaded graphs.
    version: str = "current"
        The version of the graph to retrieve.		
	The available versions are:
			- 20210422
			- 20210517
			- 20210608
			- 20210615
			- 20210617
			- 20210622
			- 20210715
			- current
    additional_graph_kwargs: Dict
        Additional graph kwargs.

    Returns
    -----------------------
    Instace of kg-microbe graph.

	
    """
    return AutomaticallyRetrievedGraph(
        graph_name="KGMicrobe",
        repository="kghub",
        version=version,
        directed=directed,
        preprocess=preprocess,
        load_nodes=load_nodes,
        verbose=verbose,
        cache=cache,
        cache_path=cache_path,
        additional_graph_kwargs=additional_graph_kwargs
    )()



"""
This file offers the methods to automatically retrieve the graph Monarch.

The graph is automatically retrieved from the MonarchInitiative repository. 


References
---------------------
Please cite the following if you use the data:

```bib
@article{mungall2017monarch,
  title={The Monarch Initiative: an integrative data and analytic platform connecting phenotypes to genotypes across species},
  author={Mungall, Christopher J and McMurry, Julie A and K{\"o}hler, Sebastian and Balhoff, James P and Borromeo, Charles and Brush, Matthew and Carbon, Seth and Conlin, Tom and Dunn, Nathan and Engelstad, Mark and others},
  journal={Nucleic acids research},
  volume={45},
  number={D1},
  pages={D712--D722},
  year={2017},
  publisher={Oxford University Press}
}
```
"""
from typing import Dict

from ..automatic_graph_retrieval import AutomaticallyRetrievedGraph
from ...ensmallen import Graph  # pylint: disable=import-error


def Monarch(
    directed: bool = False,
    preprocess: bool = True,
    load_nodes: bool = True,
    verbose: int = 2,
    cache: bool = True,
    cache_path: str = "graphs/monarchinitiative",
    version: str = "202103",
    **additional_graph_kwargs: Dict
) -> Graph:
    """Return new instance of the Monarch graph.

    The graph is automatically retrieved from the MonarchInitiative repository.	

    Parameters
    -------------------
    directed: bool = False
        Wether to load the graph as directed or undirected.
        By default false.
    preprocess: bool = True
        Whether to preprocess the graph to be loaded in 
        optimal time and memory.
    load_nodes: bool = True,
        Whether to load the nodes vocabulary or treat the nodes
        simply as a numeric range.
    verbose: int = 2,
        Wether to show loading bars during the retrieval and building
        of the graph.
    cache: bool = True
        Whether to use cache, i.e. download files only once
        and preprocess them only once.
    cache_path: str = "graphs"
        Where to store the downloaded graphs.
    version: str = "202103"
        The version of the graph to retrieve.		
	The available versions are:
			- 202012
			- 202103
    additional_graph_kwargs: Dict
        Additional graph kwargs.

    Returns
    -----------------------
    Instace of Monarch graph.

	References
	---------------------
	Please cite the following if you use the data:
	
	```bib
	@article{mungall2017monarch,
	  title={The Monarch Initiative: an integrative data and analytic platform connecting phenotypes to genotypes across species},
	  author={Mungall, Christopher J and McMurry, Julie A and K{\"o}hler, Sebastian and Balhoff, James P and Borromeo, Charles and Brush, Matthew and Carbon, Seth and Conlin, Tom and Dunn, Nathan and Engelstad, Mark and others},
	  journal={Nucleic acids research},
	  volume={45},
	  number={D1},
	  pages={D712--D722},
	  year={2017},
	  publisher={Oxford University Press}
	}
	```
    """
    return AutomaticallyRetrievedGraph(
        graph_name="Monarch",
        repository="monarchinitiative",
        version=version,
        directed=directed,
        preprocess=preprocess,
        load_nodes=load_nodes,
        verbose=verbose,
        cache=cache,
        cache_path=cache_path,
        additional_graph_kwargs=additional_graph_kwargs
    )()



"""
This file offers the methods to automatically retrieve the graph CiteSeer.

The graph is automatically retrieved from the LINQS repository. 
The CiteSeer dataset consists of 3312 scientific publications classified
into one of six classes. The citation network consists of 4732 links. Each
publication in the dataset is described by a 0/1-valued word vector indicating
the absence/presence of the corresponding word from the dictionary. The
dictionary consists of 3703 unique words.

References
---------------------
Please cite the following if you use the data:

```bib
@incollection{getoor2005link,
  title={Link-based classification},
  author={Getoor, Lise},
  booktitle={Advanced methods for knowledge discovery from complex data},
  pages={189--207},
  year={2005},
  publisher={Springer}
}

@article{sen2008collective,
  title={Collective classification in network data},
  author={Sen, Prithviraj and Namata, Galileo and Bilgic, Mustafa and Getoor, Lise and Galligher, Brian and Eliassi-Rad, Tina},
  journal={AI magazine},
  volume={29},
  number={3},
  pages={93--93},
  year={2008}
}
```
"""
from typing import Dict
from .parse_linqs import parse_linqs_incidence_matrix
from ..automatic_graph_retrieval import AutomaticallyRetrievedGraph
from ...ensmallen import Graph  # pylint: disable=import-error


def CiteSeer(
    directed: bool = False,
    preprocess: bool = True,
    load_nodes: bool = True,
    verbose: int = 2,
    cache: bool = True,
    cache_path: str = "graphs/linqs",
    version: str = "latest",
    **additional_graph_kwargs: Dict
) -> Graph:
    """Return new instance of the CiteSeer graph.

    The graph is automatically retrieved from the LINQS repository.	The CiteSeer dataset consists of 3312 scientific publications classified
	into one of six classes. The citation network consists of 4732 links. Each
	publication in the dataset is described by a 0/1-valued word vector indicating
	the absence/presence of the corresponding word from the dictionary. The
	dictionary consists of 3703 unique words.

    Parameters
    -------------------
    directed: bool = False
        Wether to load the graph as directed or undirected.
        By default false.
    preprocess: bool = True
        Whether to preprocess the graph to be loaded in 
        optimal time and memory.
    load_nodes: bool = True,
        Whether to load the nodes vocabulary or treat the nodes
        simply as a numeric range.
    verbose: int = 2,
        Wether to show loading bars during the retrieval and building
        of the graph.
    cache: bool = True
        Whether to use cache, i.e. download files only once
        and preprocess them only once.
    cache_path: str = "graphs"
        Where to store the downloaded graphs.
    version: str = "latest"
        The version of the graph to retrieve.	
    additional_graph_kwargs: Dict
        Additional graph kwargs.

    Returns
    -----------------------
    Instace of CiteSeer graph.

	References
	---------------------
	Please cite the following if you use the data:
	
	```bib
	@incollection{getoor2005link,
	  title={Link-based classification},
	  author={Getoor, Lise},
	  booktitle={Advanced methods for knowledge discovery from complex data},
	  pages={189--207},
	  year={2005},
	  publisher={Springer}
	}
	
	@article{sen2008collective,
	  title={Collective classification in network data},
	  author={Sen, Prithviraj and Namata, Galileo and Bilgic, Mustafa and Getoor, Lise and Galligher, Brian and Eliassi-Rad, Tina},
	  journal={AI magazine},
	  volume={29},
	  number={3},
	  pages={93--93},
	  year={2008}
	}
	```
    """
    return AutomaticallyRetrievedGraph(
        graph_name="CiteSeer",
        repository="linqs",
        version=version,
        directed=directed,
        preprocess=preprocess,
        load_nodes=load_nodes,
        verbose=verbose,
        cache=cache,
        cache_path=cache_path,
        additional_graph_kwargs=additional_graph_kwargs,
		callbacks=[
			parse_linqs_incidence_matrix
		],
		callbacks_arguments=[
		    {
		        "cites_path": "citeseer/citeseer/citeseer.cites",
		        "content_path": "citeseer/citeseer/citeseer.content",
		        "node_path": "nodes.tsv",
		        "edge_path": "edges.tsv"
		    }
		]
    )()



"""This sub-module offers methods to automatically retrieve the graphs from NetworkRepository repository."""

from .c5009 import C5009
from .opsahlsouthernwomen import OpsahlSouthernwomen
from .socfbnorthwestern25 import SocfbNorthwestern25
from .gen400p0965 import Gen400P0965
from .gen400p0975 import Gen400P0975
from .san400073 import San400073
from .g29 import G29
from .cl10002d1trial1 import Cl10002d1Trial1
from .g39 import G39
from .socfbusc35 import SocfbUsc35
from .jagmesh7 import Jagmesh7
from .aa3 import Aa3
from .zhishizhwikiinternallink import ZhishiZhwikiInternallink
from .sw100030d2trial3 import Sw100030d2Trial3
from .techascaida import TechAsCaida
from .scldoor import ScLdoor
from .trec9 import Trec9
from .socfbbowdoin47 import SocfbBowdoin47
from .bcsstm39 import Bcsstm39
from .dsjc5005 import Dsjc5005
from .p2pgnutella30 import P2pGnutella30
from .tube2 import Tube2
from .email import Email
from .nr208bit import NR208bit
from .ex6 import Ex6
from .sw100030d1trial2 import Sw100030d1Trial2
from .sw100040d3trial3 import Sw100040d3Trial3
from .cl100001d8trial1 import Cl100001d8Trial1
from .manna9 import MannA9
from .hamming104 import Hamming104
from .bioscht import BioScHt
from .infeuroroad import InfEuroroad
from .cl1000001d7trial1 import Cl1000001d7Trial1
from .manna81 import MannA81
from .tsyl201 import Tsyl201
from .g4 import G4
from .sw1000050d3trial2 import Sw1000050d3Trial2
from .yahoomsg import YahooMsg
from .skirt import Skirt
from .net150 import Net150
from .dbpediateam import DbpediaTeam
from .powerbcspwr09 import PowerBcspwr09
from .dictionary28 import Dictionary28
from .trec10 import Trec10
from .barth5 import Barth5
from .foldoc import Foldoc
from .sw10040d1trial2 import Sw10040d1Trial2
from .bcsstm06 import Bcsstm06
from .sw1000060d1trial2 import Sw1000060d1Trial2
from .sw10040d2trial3 import Sw10040d2Trial3
from .ecostmarks import EcoStmarks
from .sw1000060d2trial3 import Sw1000060d2Trial3
from .patentcite import Patentcite
from .johnson3224 import Johnson3224
from .emaileuall import EmailEuall
from .socsinaweibo import SocSinaweibo
from .cage14 import Cage14
from .g16 import G16
from .cl10001d9trial1 import Cl10001d9Trial1
from .actorcollaboration import ActorCollaboration
from .kohonen import Kohonen
from .sochighschoolmoreno import SocHighschoolMoreno
from .biplane9 import Biplane9
from .brock4001 import Brock4001
from .plc4030l5 import Plc4030L5
from .socfbmsu24 import SocfbMsu24
from .socfbjohnshopkins55 import SocfbJohnshopkins55
from .ljournal2008 import Ljournal2008
from .ig518 import Ig518
from .g64 import G64
from .rajat08 import Rajat08
from .finance256 import Finance256
from .soclivejournal import SocLivejournal
from .air06 import Air06
from .cl100002d0trial1 import Cl100002d0Trial1
from .febody import FeBody
from .bcsstk31 import Bcsstk31
from .socanuresidence import SocAnuResidence
from .engine import Engine
from .sw10030d3trial3 import Sw10030d3Trial3
from .cage3 import Cage3
from .cahepth import CaHepth
from .foodwebbaydry import FoodwebBaydry
from .socfboberlin44 import SocfbOberlin44
from .soctwitter import SocTwitter
from .cl1000001d9trial3 import Cl1000001d9Trial3
from .miscimdbbi import MiscImdbBi
from .pkustk04 import Pkustk04
from .pkustk14 import Pkustk14
from .bnhumanjung import BNHumanJung
from .sw10050d1trial1 import Sw10050d1Trial1
from .bioscts import BioScTs
from .g52 import G52
from .sw100060d2trial1 import Sw100060d2Trial1
from .dbpediarecordlabel import DbpediaRecordlabel
from .g42 import G42
from .powerbcspwr10 import PowerBcspwr10
from .cl10000002d0trial1 import Cl10000002d0Trial1
from .socfbmaryland58 import SocfbMaryland58
from .rw496 import Rw496
from .se import Se
from .cl10k1d8l5 import Cl10k1d8L5
from .roadnetpa import RoadnetPa
from .bcspwr03 import Bcspwr03
from .socdelicious import SocDelicious
from .g30 import G30
from .roadnetherlandsosm import RoadNetherlandsOsm
from .dolphins import Dolphins
from .infroadnetpa import InfRoadnetPa
from .socfbbc17 import SocfbBc17
from .pcrystk03 import Pcrystk03
from .struct3 import Struct3
from .techarenasmeta import TechArenasMeta
from .bcsstm20 import Bcsstm20
from .patents import Patents
from .affflickrusergroups import AffFlickrUserGroups
from .ash958 import Ash958
from .phat15003 import PHat15003
from .tf13 import Tf13
from .cl10000001d8trial1 import Cl10000001d8Trial1
from .socfbhoward90 import SocfbHoward90
from .enzymes8 import Enzymes8
from .cfat2002 import CFat2002
from .rajat01 import Rajat01
from .sw1000030d2trial1 import Sw1000030d2Trial1
from .pds10 import Pds10
from .socdolphins import SocDolphins
from .ig511 import Ig511
from .lshp1561 import Lshp1561
from .ash292 import Ash292
from .socfbamerican75 import SocfbAmerican75
from .socfbmit import SocfbMit
from .gupta1 import Gupta1
from .socfbhamilton46 import SocfbHamilton46
from .san200072 import San200072
from .dsjc10005 import Dsjc10005
from .cl1000002d1trial3 import Cl1000002d1Trial3
from .p2pgnutella06 import P2pGnutella06
from .packing500x100x100b050 import Packing500x100x100B050
from .biocegt import BioCeGt
from .actormovie import ActorMovie
from .miscjungcodedep import MiscJungCodeDep
from .phat3003 import PHat3003
from .socslashdot import SocSlashdot
from .data import Data
from .ash331 import Ash331
from .uk2002 import Uk2002
from .erdos992 import Erdos992
from .erdos982 import Erdos982
from .ig58 import Ig58
from .phat10002 import PHat10002
from .uspowergrid import Uspowergrid
from .affgithubuser2project import AffGithubUser2project
from .rtretweet import RtRetweet
from .copresencethiers13 import CopresenceThiers13
from .chesapeake import Chesapeake
from .sstmodel import Sstmodel
from .sw1000040d3trial1 import Sw1000040d3Trial1
from .johnson844 import Johnson844
from .sw10060d3trial1 import Sw10060d3Trial1
from .cl10001d7trial3 import Cl10001d7Trial3
from .affamazoncopurchases import AffAmazonCopurchases
from .camathscinetdir import CaMathscinetDir
from .g43 import G43
from .g53 import G53
from .affdigg import AffDigg
from .sw100060d1trial1 import Sw100060d1Trial1
from .cacondmat import CaCondmat
from .dblpcite import DblpCite
from .cl1000001d9trial2 import Cl1000001d9Trial2
from .sw10050d2trial1 import Sw10050d2Trial1
from .amazon0302 import Amazon0302
from .amazon0312 import Amazon0312
from .techp2pgnutella import TechP2pGnutella
from .fbcmucarnegie49 import FbCmuCarnegie49
from .biocecx import BioCeCx
from .barth import Barth
from .pkustk05 import Pkustk05
from .srb1 import Srb1
from .webindochina2004all import WebIndochina2004All
from .pcrystk02 import Pcrystk02
from .socslashdottrustall import SocSlashdotTrustAll
from .maayanfigeys import MaayanFigeys
from .biocelegans import BioCelegans
from .as735 import As735
from .bcsstm21 import Bcsstm21
from .asskitter import AsSkitter
from .hollywood2009 import Hollywood2009
from .caerdos992 import CaErdos992
from .dd497 import Dd497
from .arenasmeta import ArenasMeta
from .socfbfsu53 import SocfbFsu53
from .canetscience import CaNetscience
from .soctwitterfollows import SocTwitterFollows
from .avessparrowsocial import AvesSparrowSocial
from .socfbcmu import SocfbCmu
from .scpkustk11 import ScPkustk11
from .webepa import WebEpa
from .bcspwr02 import Bcspwr02
from .g31 import G31
from .chem97zt import Chem97zt
from .techinternetas import TechInternetAs
from .socfbwake73 import SocfbWake73
from .zhishibaiduinternallink import ZhishiBaiduInternallink
from .bfly import Bfly
from .avesweaversocial import AvesWeaverSocial
from .dbpediacountry import DbpediaCountry
from .net25 import Net25
from .biohumangene1 import BioHumanGene1
from .cl1000002d1trial2 import Cl1000002d1Trial2
from .zhishihudonginternallink import ZhishiHudongInternallink
from .bcsstk29 import Bcsstk29
from .biocepg import BioCePg
from .socpokec import SocPokec
from .us04 import Us04
from .sw1000030d1trial1 import Sw1000030d1Trial1
from .copter2 import Copter2
from .socfbmichigan23 import SocfbMichigan23
from .brock2004 import Brock2004
from .tf12 import Tf12
from .phat15002 import PHat15002
from .youtubegroupmemberships import YoutubeGroupmemberships
from .connectus import Connectus
from .ig510 import Ig510
from .roadgermanyosm import RoadGermanyOsm
from .rajat10 import Rajat10
from .biohscx import BioHsCx
from .ecofoodwebbaywet import EcoFoodwebBaywet
from .bas1lp import Bas1lp
from .ig59 import Ig59
from .rtretweetcrawl import RtRetweetCrawl
from .socfbwisconsin87 import SocfbWisconsin87
from .glossgt import Glossgt
from .cl10001d7trial2 import Cl10001d7Trial2
from .socgoogleplus import SocGooglePlus
from .phat10003 import PHat10003
from .lshp2233 import Lshp2233
from .pfinan512 import Pfinan512
from .maayanfaa import MaayanFaa
from .roadnettx import RoadnetTx
from .sw100050d3trial1 import Sw100050d3Trial1
from .caaminer import CaAminer
from .socfbtexas80 import SocfbTexas80
from .sw100030d2trial2 import Sw100030d2Trial2
from .zhishibaidurelatedpages import ZhishiBaiduRelatedpages
from .wbcsstanford import WbCsStanford
from .jagmesh6 import Jagmesh6
from .sw100030d1trial3 import Sw100030d1Trial3
from .p2pgnutella31 import P2pGnutella31
from .reactome import Reactome
from .github import Github
from .socfbberkeley13 import SocfbBerkeley13
from .zhishihudongrelatedpages import ZhishiHudongRelatedpages
from .trec8 import Trec8
from .san400072 import San400072
from .webitalycnr2000 import WebItalycnr2000
from .webstanford import WebStanford
from .webindochina2004 import WebIndochina2004
from .socfbnortheastern19 import SocfbNortheastern19
from .stanford import Stanford
from .cfat5001 import CFat5001
from .socsignbitcoinotc import SocSignBitcoinotc
from .flickr import Flickr
from .g38 import G38
from .sw1000050d3trial3 import Sw1000050d3Trial3
from .g5 import G5
from .scshipsec1 import ScShipsec1
from .socfbcolgate88 import SocfbColgate88
from .arabic2005 import Arabic2005
from .ccc import Ccc
from .barth4 import Barth4
from .c20009 import C20009
from .soclastfm import SocLastfm
from .trec11 import Trec11
from .socbuzznet import SocBuzznet
from .usroads48 import Usroads48
from .biogridworm import BioGridWorm
from .sw100040d3trial2 import Sw100040d3Trial2
from .socfbnotredame57 import SocfbNotredame57
from .epa import Epa
from .ermd import ErMd
from .g17 import G17
from .socfbindiana69 import SocfbIndiana69
from .cvxbqp1 import Cvxbqp1
from .sw1000060d1trial3 import Sw1000060d1Trial3
from .hugebubbles00010 import Hugebubbles00010
from .sw10040d1trial3 import Sw10040d1Trial3
from .hugebubbles00000 import Hugebubbles00000
from .socfbcolumbia2 import SocfbColumbia2
from .cage15 import Cage15
from .sw1000060d2trial2 import Sw1000060d2Trial2
from .roadusroads import RoadUsroads
from .socacademia import SocAcademia
from .sw10040d2trial2 import Sw10040d2Trial2
from .karate import Karate
from .sw10030d3trial2 import Sw10030d3Trial2
from .sanr20009 import Sanr20009
from .bcsstk30 import Bcsstk30
from .cl10m1d8l5 import Cl10m1d8L5
from .wordnetwords import WordnetWords
from .miscfootball import MiscFootball
from .egogplus import EgoGplus
from .socfbunc28 import SocfbUnc28
from .webedu import WebEdu
from .cagrqc import CaGrqc
from .biowormnetv3 import BioWormnetV3
from .mri1 import Mri1
from .rajat09 import Rajat09
from .g65 import G65
from .grid1 import Grid1
from .hamming62 import Hamming62
from .gearbox import Gearbox
from .bcsstm23 import Bcsstm23
from .techascaida20071105 import TechAsCaida20071105
from .webberkstandir import WebBerkstanDir
from .socpokecrelationships import SocPokecRelationships
from .socadvogato import SocAdvogato
from .roadgreatbritainosm import RoadGreatBritainOsm
from .brock8004 import Brock8004
from .socfbstanford3 import SocfbStanford3
from .roadminnesota import RoadMinnesota
from .webspamdetection import WebSpamDetection
from .bcspwr10 import Bcspwr10
from .g23 import G23
from .scpkustk13 import ScPkustk13
from .chem97ztz import Chem97ztz
from .ecoeverglades import EcoEverglades
from .socfbkonect import SocfbKonect
from .youtubelinks import YoutubeLinks
from .sphere3 import Sphere3
from .emailuniv import EmailUniv
from .ascaida20071105 import AsCaida20071105
from .cl10000002d0trial2 import Cl10000002d0Trial2
from .sw100060d1trial3 import Sw100060d1Trial3
from .lshp1270 import Lshp1270
from .g51 import G51
from .sw100060d2trial2 import Sw100060d2Trial2
from .petstercarnivore import PetsterCarnivore
from .g41 import G41
from .pkustk07 import Pkustk07
from .sw10050d1trial2 import Sw10050d1Trial2
from .dbpediaoccupation import DbpediaOccupation
from .socfbmaine59 import SocfbMaine59
from .socfbuillinois20 import SocfbUillinois20
from .socfbcarnegie49 import SocfbCarnegie49
from .techp2p import TechP2p
from .sw10050d2trial3 import Sw10050d2Trial3
from .football import Football
from .phat10001 import PHat10001
from .sw1000040d3trial2 import Sw1000040d3Trial2
from .c10009 import C10009
from .sw10060d3trial2 import Sw10060d3Trial2
from .erdos991 import Erdos991
from .dd199 import Dd199
from .webwikipedia2009 import WebWikipedia2009
from .erdos981 import Erdos981
from .webuk2005 import WebUk2005
from .socfbbaylor93 import SocfbBaylor93
from .fe4elt2 import Fe4elt2
from .abb313 import Abb313
from .trecwt10g import TrecWt10g
from .socfbreed98 import SocfbReed98
from .sw100050d3trial3 import Sw100050d3Trial3
from .socfbnyu9 import SocfbNyu9
from .p2pgnutella05 import P2pGnutella05
from .ecofoodwebbaydry import EcoFoodwebBaydry
from .gupta2 import Gupta2
from .san200071 import San200071
from .advogato import Advogato
from .socfbbu10 import SocfbBu10
from .cacoauthorsdblp import CaCoauthorsDblp
from .cfat2001 import CFat2001
from .rttwittercopen import RtTwitterCopen
from .roaditalyosm import RoadItalyOsm
from .biogridfruitfly import BioGridFruitfly
from .socfbduke14 import SocfbDuke14
from .sw1000030d2trial2 import Sw1000030d2Trial2
from .rajat02 import Rajat02
from .ig512 import Ig512
from .opsahlusairport import OpsahlUsairport
from .socfbusf51 import SocfbUsf51
from .socgplus import SocGplus
from .tf10 import Tf10
from .troll import Troll
from .cl10000001d8trial2 import Cl10000001d8Trial2
from .techpgp import TechPgp
from .sw1000030d1trial3 import Sw1000030d1Trial3
from .copresenceinvs15 import CopresenceInvs15
from .trec13 import Trec13
from .webgoogledir import WebGoogleDir
from .ascaida import AsCaida
from .cca import Cca
from .fetooth import FeTooth
from .sw1000050d3trial1 import Sw1000050d3Trial1
from .g7 import G7
from .g48 import G48
from .socfbor import SocfbOr
from .socfbuc61 import SocfbUc61
from .g58 import G58
from .caastroph import CaAstroph
from .cl1000001d7trial2 import Cl1000001d7Trial2
from .biodmht import BioDmHt
from .socfbupenn7 import SocfbUpenn7
from .emaileu import EmailEu
from .ecoflorida import EcoFlorida
from .cage9 import Cage9
from .cl100001d8trial2 import Cl100001d8Trial2
from .dbpediagenre import DbpediaGenre
from .tube1 import Tube1
from .ex5 import Ex5
from .sw100030d1trial1 import Sw100030d1Trial1
from .jagmesh4 import Jagmesh4
from .nr145bit import NR145bit
from .journals import Journals
from .hamming84 import Hamming84
from .hepth import HepTh
from .lock3491 import Lock3491
from .eva import Eva
from .cl10002d1trial2 import Cl10002d1Trial2
from .geom import Geom
from .bcspwr09 import Bcspwr09
from .socfbtufts18 import SocfbTufts18
from .soctwittermpisws import SocTwitterMpiSws
from .soctwitterfollowsmun import SocTwitterFollowsMun
from .socfbmu78 import SocfbMu78
from .cl100002d0trial2 import Cl100002d0Trial2
from .bcsstk32 import Bcsstk32
from .roadnetca import RoadnetCa
from .affwikiwordbypage import AffWikiWordbypage
from .as20000102 import As20000102
from .cnr2000 import Cnr2000
from .infroadnetca import InfRoadnetCa
from .jgl009 import Jgl009
from .air05 import Air05
from .rail2586 import Rail2586
from .pwt import Pwt
from .socepinions1 import SocEpinions1
from .g67 import G67
from .tf19 import Tf19
from .pattern1 import Pattern1
from .socfbuva16 import SocfbUva16
from .nasa4704 import Nasa4704
from .techcaidarouterlevel import TechCaidarouterlevel
from .cs4 import Cs4
from .ash608 import Ash608
from .hugetric00000 import Hugetric00000
from .hugetric00010 import Hugetric00010
from .bioyeastproteininter import BioYeastProteinInter
from .socfirmhitech import SocFirmHiTech
from .g15 import G15
from .socorkut import SocOrkut
from .miscreuters911 import MiscReuters911
from .cl10001d9trial2 import Cl10001d9Trial2
from .in2004 import In2004
from .brock4002 import Brock4002
from .netz4504 import Netz4504
from .powerusgrid import PowerUsGrid
from .roadeuroroad import RoadEuroroad
from .bcsstm05 import Bcsstm05
from .ragusa16 import Ragusa16
from .opsahlpowergrid import OpsahlPowergrid
from .socfbusfca72 import SocfbUsfca72
from .sw10040d1trial1 import Sw10040d1Trial1
from .socfboklahoma97 import SocfbOklahoma97
from .sw1000060d1trial1 import Sw1000060d1Trial1
from .socdouban import SocDouban
from .socfbbucknell39 import SocfbBucknell39
from .cl1000001d7trial3 import Cl1000001d7Trial3
from .caactorcollaboration import CaActorCollaboration
from .nr3elt import NR3elt
from .websk2005 import WebSk2005
from .cl100001d8trial3 import Cl100001d8Trial3
from .sw100040d3trial1 import Sw100040d3Trial1
from .cage8 import Cage8
from .citpatent import CitPatent
from .biohslc import BioHsLc
from .trec12 import Trec12
from .caidarouterlevel import Caidarouterlevel
from .dbpedialocation import DbpediaLocation
from .g59 import G59
from .g49 import G49
from .g6 import G6
from .it2004 import It2004
from .cfat5002 import CFat5002
from .bcspwr08 import Bcspwr08
from .cl10002d1trial3 import Cl10002d1Trial3
from .san400071 import San400071
from .socfbuf21 import SocfbUf21
from .slashdotzoo import SlashdotZoo
from .sw1000060d3l2 import Sw1000060d3L2
from .ex4 import Ex4
from .orkutlinks import OrkutLinks
from .ibm32 import Ibm32
from .appu import Appu
from .sw100030d2trial1 import Sw100030d2Trial1
from .socdogster import SocDogster
from .jagmesh5 import Jagmesh5
from .grid2 import Grid2
from .g66 import G66
from .mri2 import Mri2
from .diag import Diag
from .socfbuchicago30 import SocfbUchicago30
from .socfbwilliams40 import SocfbWilliams40
from .actor import Actor
from .socfbbrown11 import SocfbBrown11
from .t520 import T520
from .tf18 import Tf18
from .biocelc import BioCeLc
from .sw10030d3trial1 import Sw10030d3Trial1
from .t60k import T60k
from .bcsstk33 import Bcsstk33
from .crack import Crack
from .cl100002d0trial3 import Cl100002d0Trial3
from .socfbsanta74 import SocfbSanta74
from .socfbcornell5 import SocfbCornell5
from .air04 import Air04
from .petsterfriendshipsdog import PetsterFriendshipsDog
from .sw1000060d2trial1 import Sw1000060d2Trial1
from .biogridfissionyeast import BioGridFissionYeast
from .sw10040d2trial1 import Sw10040d2Trial1
from .pct20stif import Pct20stif
from .comyoutube import ComYoutube
from .petsterfriendshipscat import PetsterFriendshipsCat
from .socfbharvard1 import SocfbHarvard1
from .hugetrace00000 import Hugetrace00000
from .brock4003 import Brock4003
from .polblogs import Polblogs
from .hugetrace00010 import Hugetrace00010
from .cl10001d9trial3 import Cl10001d9Trial3
from .roget import Roget
from .g14 import G14
from .webpolblogs import WebPolblogs
from .arenaspgp import ArenasPgp
from .netscience import Netscience
from .socfbvirginia63 import SocfbVirginia63
from .plc6030l2 import Plc6030L2
from .gene import Gene
from .foodwebbaywet import FoodwebBaywet
from .g22 import G22
from .indochina2004 import Indochina2004
from .bcspwr01 import Bcspwr01
from .biogridhuman import BioGridHuman
from .coauthorsciteseer import Coauthorsciteseer
from .socblogcatalog import SocBlogcatalog
from .biosccc import BioScCc
from .socfoursquare import SocFoursquare
from .bcsstm22 import Bcsstm22
from .qa8fm import Qa8fm
from .socfbwellesley22 import SocfbWellesley22
from .halfb import Halfb
from .comamazon import ComAmazon
from .roadroadusa import RoadRoadUsa
from .socfbuconn import SocfbUconn
from .emailenrononly import EmailEnronOnly
from .ucidatagama import UcidataGama
from .dd68 import Dd68
from .sw10050d1trial3 import Sw10050d1Trial3
from .socfbuga50 import SocfbUga50
from .pkustk06 import Pkustk06
from .cl1000001d9trial1 import Cl1000001d9Trial1
from .sw10050d2trial2 import Sw10050d2Trial2
from .socyoutube import SocYoutube
from .stufe10 import Stufe10
from .sw100060d1trial2 import Sw100060d1Trial2
from .cl10000002d0trial3 import Cl10000002d0Trial3
from .sphere2 import Sphere2
from .enzymes118 import Enzymes118
from .socfbindiana import SocfbIndiana
from .opt1 import Opt1
from .g40 import G40
from .sw100060d2trial3 import Sw100060d2Trial3
from .g50 import G50
from .econpsmigr2 import EconPsmigr2
from .sw100050d3trial2 import Sw100050d3Trial2
from .socfbmit8 import SocfbMit8
from .p2pgnutella04 import P2pGnutella04
from .dblpauthor import DblpAuthor
from .citationciteseer import Citationciteseer
from .cl10001d7trial1 import Cl10001d7Trial1
from .sw10060d3trial3 import Sw10060d3Trial3
from .sw1000040d3trial3 import Sw1000040d3Trial3
from .infopenflights import InfOpenflights
from .nr08blocks import NR08blocks
from .ig513 import Ig513
from .channel500x100x100b050 import Channel500x100x100B050
from .techascaida2007 import TechAsCaida2007
from .sw1000030d2trial3 import Sw1000030d2Trial3
from .twitter import Twitter
from .johnson824 import Johnson824
from .cl10000001d8trial3 import Cl10000001d8Trial3
from .sw1000030d1trial2 import Sw1000030d1Trial2
from .copter1 import Copter1
from .phat15001 import PHat15001
from .tf11 import Tf11
from .dixmaanl import Dixmaanl
from .biohumangene2 import BioHumanGene2
from .fsfa import FsFa
from .cl1000002d1trial1 import Cl1000002d1Trial1
from .wave import Wave
from .gupta3 import Gupta3
from .jgl011 import Jgl011
from .dd242 import Dd242
from .fesphere import FeSphere
from .bcsstm08 import Bcsstm08
from .socfbnipsego import SocfbNipsEgo
from .net41 import Net41
from .techarenasjazz import TechArenasJazz
from .cl10001d8trial3 import Cl10001d8Trial3
from .socfbvermont70 import SocfbVermont70
from .socdigg import SocDigg
from .sw10040d3trial1 import Sw10040d3Trial1
from .uk2005 import Uk2005
from .infpower import InfPower
from .sw1000060d3trial1 import Sw1000060d3Trial1
from .webuk2005all import WebUk2005All
from .lock1074 import Lock1074
from .petsterfriendshipshamster import PetsterFriendshipsHamster
from .socfbrutgers89 import SocfbRutgers89
from .cl100002d1trial3 import Cl100002d1Trial3
from .roadasiaosm import RoadAsiaOsm
from .sw10030d2trial1 import Sw10030d2Trial1
from .cfat50010 import CFat50010
from .brock2002 import Brock2002
from .tf14 import Tf14
from .rajat06 import Rajat06
from .ig516 import Ig516
from .as22july06 import As22july06
from .cfat2005 import CFat2005
from .webkbwisc import WebkbWisc
from .cl10000001d7trial1 import Cl10000001d7Trial1
from .socfbucsc68 import SocfbUcsc68
from .shock9 import Shock9
from .san200091 import San200091
from .condmat import CondMat
from .cities import Cities
from .rail4284 import Rail4284
from .socfbyale4 import SocfbYale4
from .lshp3466 import Lshp3466
from .s4dkt3m2 import S4dkt3m2
from .debr import Debr
from .bcspwr04 import Bcspwr04
from .g37 import G37
from .g27 import G27
from .sw100030d3trial1 import Sw100030d3Trial1
from .maayanstelzl import MaayanStelzl
from .struct4 import Struct4
from .socfbmich67 import SocfbMich67
from .cl10002d0trial3 import Cl10002d0Trial3
from .kleemin import Kleemin
from .jagmesh9 import Jagmesh9
from .lp1 import Lp1
from .trec7 import Trec7
from .phat7003 import PHat7003
from .affwikienarticlecat import AffWikiEnArticleCat
from .cage4 import Cage4
from .sw1000050d1trial1 import Sw1000050d1Trial1
from .socfbuf import SocfbUf
from .erdos971 import Erdos971
from .pkustk03 import Pkustk03
from .pkustk13 import Pkustk13
from .scnasasrb import ScNasasrb
from .g55 import G55
from .g45 import G45
from .california import California
from .roadluxembourgosm import RoadLuxembourgOsm
from .cl100001d9trial3 import Cl100001d9Trial3
from .sw100040d2trial1 import Sw100040d2Trial1
from .cacsphd import CaCsphd
from .ucidatazachary import UcidataZachary
from .cl1000002d0trial1 import Cl1000002d0Trial1
from .socphysicians import SocPhysicians
from .soclivejournal1 import SocLivejournal1
from .crystm02 import Crystm02
from .g63 import G63
from .nr130bit import NR130bit
from .socfbgwu54 import SocfbGwu54
from .dblp2010 import Dblp2010
from .hamming64 import Hamming64
from .amazon0601 import Amazon0601
from .soclocbrightkite import SocLocBrightkite
from .emailenronlarge import EmailEnronLarge
from .c40005 import C40005
from .sw1000030d3trial3 import Sw1000030d3Trial3
from .socthemarker import SocThemarker
from .infusair97 import InfUsair97
from .roadroadnetpa import RoadRoadnetPa
from .pli import Pli
from .maayanvidal import MaayanVidal
from .socfbucla import SocfbUcla
from .soctribes import SocTribes
from .cl10000001d9trial3 import Cl10000001d9Trial3
from .socfbauburn71 import SocfbAuburn71
from .webbase1m import Webbase1m
from .amazon0505 import Amazon0505
from .sw1000040d2trial3 import Sw1000040d2Trial3
from .p2pgnutella08 import P2pGnutella08
from .sw10060d2trial3 import Sw10060d2Trial3
from .bcsstm11 import Bcsstm11
from .copapersdblp import CoPapersDblp
from .sfhhconfsensor import SfhhConfSensor
from .sw1000040d1trial2 import Sw1000040d1Trial2
from .cage13 import Cage13
from .enzymes296 import Enzymes296
from .sw10060d1trial2 import Sw10060d1Trial2
from .epinions import Epinions
from .ig56 import Ig56
from .rgg010 import Rgg010
from .socfbtennessee95 import SocfbTennessee95
from .sw100050d2trial2 import Sw100050d2Trial2
from .coater1 import Coater1
from .sw100050d1trial3 import Sw100050d1Trial3
from .flickrgroupmemberships import FlickrGroupmemberships
from .cl10000002d1trial3 import Cl10000002d1Trial3
from .lesmis import Lesmis
from .socepinions import SocEpinions
from .g3rmt3m3 import G3rmt3m3
from .infectdublin import InfectDublin
from .sw100060d3trial3 import Sw100060d3Trial3
from .feocean import FeOcean
from .gen200p0955 import Gen200P0955
from .g3 import G3
from .usair97 import Usair97
from .c2509 import C2509
from .cl100001d7trial1 import Cl100001d7Trial1
from .socfbtemple83 import SocfbTemple83
from .sanr40005 import Sanr40005
from .lederberg import Lederberg
from .lshp1882 import Lshp1882
from .lock2232 import Lock2232
from .webhudong import WebHudong
from .cl1000001d8trial1 import Cl1000001d8Trial1
from .sw10050d3trial2 import Sw10050d3Trial2
from .internet import Internet
from .dbpediaproducer import DbpediaProducer
from .sochamsterster import SocHamsterster
from .net125 import Net125
from .socfbuciuni import SocfbUciUni
from .coauthorsdblp import Coauthorsdblp
from .keller6 import Keller6
from .fbmessages import FbMessages
from .socfbvassar85 import SocfbVassar85
from .socanybeat import SocAnybeat
from .brack2 import Brack2
from .socfbtrinity100 import SocfbTrinity100
from .aa4 import Aa4
from .rthiggs import RtHiggs
from .ex1 import Ex1
from .sw1000030d3trial2 import Sw1000030d3Trial2
from .socslashdotzoo import SocSlashdotZoo
from .san400091 import San400091
from .phat5001 import PHat5001
from .socfbprinceton12 import SocfbPrinceton12
from .cl10000001d9trial2 import Cl10000001d9Trial2
from .contiguoususa import ContiguousUsa
from .cegb3024 import Cegb3024
from .citpatents import CitPatents
from .biocegn import BioCeGn
from .san1000 import San1000
from .socfbaanon import SocfbAAnon
from .lshp2614 import Lshp2614
from .g62 import G62
from .crystm03 import Crystm03
from .socfbsyracuse56 import SocfbSyracuse56
from .sw100050d2trial3 import Sw100050d2Trial3
from .g10 import G10
from .divorce import Divorce
from .roadchesapeake import RoadChesapeake
from .curtis54 import Curtis54
from .ig57 import Ig57
from .flickredges import Flickredges
from .sw100050d1trial2 import Sw100050d1Trial2
from .socslashdot0811 import SocSlashdot0811
from .linux import Linux
from .sw10060d2trial2 import Sw10060d2Trial2
from .p2pgnutella09 import P2pGnutella09
from .sw1000040d2trial2 import Sw1000040d2Trial2
from .sw10060d1trial3 import Sw10060d1Trial3
from .enzymes297 import Enzymes297
from .cage12 import Cage12
from .afforkutuser2groups import AffOrkutUser2groups
from .sw1000040d1trial3 import Sw1000040d1Trial3
from .bnmouseretina import BNMouseRetina
from .livejournalgroupmemberships import LivejournalGroupmemberships
from .webit2004 import WebIt2004
from .socfbuc64 import SocfbUc64
from .g2 import G2
from .biodmcx import BioDmCx
from .sw10050d3trial3 import Sw10050d3Trial3
from .cadblp2010 import CaDblp2010
from .socfbpepperdine86 import SocfbPepperdine86
from .wikiencat import WikiEnCat
from .reuters911 import Reuters911
from .cl10000002d1trial2 import Cl10000002d1Trial2
from .webwikichinternal import WebWikiChInternal
from .hamming102 import Hamming102
from .crew1 import Crew1
from .eris1176 import Eris1176
from .socfbucsb37 import SocfbUcsb37
from .bnflydrosophilamedulla import BNFlyDrosophilaMedulla
from .sw100060d3trial2 import Sw100060d3Trial2
from .gen200p0944 import Gen200P0944
from .oregon1 import Oregon1
from .ins2 import Ins2
from .sk2005 import Sk2005
from .aa5 import Aa5
from .jagmesh1 import Jagmesh1
from .socgowalla import SocGowalla
from .tomographic1 import Tomographic1
from .jazz import Jazz
from .caimdb import CaImdb
from .lshp3025 import Lshp3025
from .dd687 import Dd687
from .infcontiguoususa import InfContiguousUsa
from .nw14 import Nw14
from .arenasjazz import ArenasJazz
from .cyl6 import Cyl6
from .scimet import Scimet
from .socfbsmith60 import SocfbSmith60
from .gen400p0955 import Gen400P0955
from .roadusroads48 import RoadUsroads48
from .bcsstm19 import Bcsstm19
from .net50 import Net50
from .bcsstm09 import Bcsstm09
from .m14b import M14b
from .mip1 import Mip1
from .ford1 import Ford1
from .dd21 import Dd21
from .biodmela import BioDmela
from .smagri import Smagri
from .cl10001d8trial2 import Cl10001d8Trial2
from .harvard500 import Harvard500
from .gent113 import Gent113
from .dd349 import Dd349
from .aa03 import Aa03
from .techas22july06 import TechAs22july06
from .sanr20007 import Sanr20007
from .brock2003 import Brock2003
from .enzymes123 import Enzymes123
from .tf15 import Tf15
from .biosclc import BioScLc
from .socslashdot0902 import SocSlashdot0902
from .cl100002d1trial2 import Cl100002d1Trial2
from .wing import Wing
from .sw10030d1trial1 import Sw10030d1Trial1
from .nr192bit import NR192bit
from .ig517 import Ig517
from .rajat07 import Rajat07
from .eu2005 import Eu2005
from .jagmesh8 import Jagmesh8
from .brock8001 import Brock8001
from .erdos02 import Erdos02
from .copapersciteseer import CoPapersCiteseer
from .cl10002d0trial2 import Cl10002d0Trial2
from .bcsstm26 import Bcsstm26
from .trec6 import Trec6
from .techasskitter import TechAsSkitter
from .webarabic2005 import WebArabic2005
from .citdblp import CitDblp
from .wikitalk import WikiTalk
from .lshp1009 import Lshp1009
from .socfblehigh96 import SocfbLehigh96
from .affdbpediausers2country import AffDbpediaUsers2country
from .socfbtulane29 import SocfbTulane29
from .manna45 import MannA45
from .g26 import G26
from .nr598a import NR598a
from .dbpediaall import DbpediaAll
from .bcspwr05 import Bcspwr05
from .cegb3306 import Cegb3306
from .g36 import G36
from .pf2177 import Pf2177
from .manna27 import MannA27
from .soclivejournal07 import SocLivejournal07
from .socfbgeorgetown15 import SocfbGeorgetown15
from .sw100040d1trial1 import Sw100040d1Trial1
from .g44 import G44
from .g54 import G54
from .odlis import Odlis
from .cl100001d9trial2 import Cl100001d9Trial2
from .cage5 import Cage5
from .phat7002 import PHat7002
from .dbpediastarring import DbpediaStarring
from .sw1000050d2trial1 import Sw1000050d2Trial1
from .webspam import WebSpam
from .pkustk12 import Pkustk12
from .webbaidubaike import WebBaiduBaike
from .pkustk02 import Pkustk02
from .webclueweb09 import WebClueweb09
from .webcc12payleveldomain import WebCc12Payleveldomain
from .socfbbingham82 import SocfbBingham82
from .bioyeast import BioYeast
from .citeulikeui import CiteulikeUi
from .citeuliketi import CiteulikeTi
from .lpl1 import Lpl1
from .bioscgt import BioScGt
from .sw100050d2trial1 import Sw100050d2Trial1
from .coater2 import Coater2
from .copresencelyonschool import CopresenceLyonschool
from .cage10 import Cage10
from .sw1000040d1trial1 import Sw1000040d1Trial1
from .enzymes295 import Enzymes295
from .sw10060d1trial1 import Sw10060d1Trial1
from .cahepph import CaHepph
from .webwebbase2001all import WebWebbase2001All
from .bcsstm02 import Bcsstm02
from .nr176bit import NR176bit
from .emailenron import EmailEnron
from .phat5003 import PHat5003
from .primaryschoolproximity import PrimarySchoolProximity
from .socfbwilliam77 import SocfbWilliam77
from .air02 import Air02
from .socfbumass92 import SocfbUmass92
from .minnesota import Minnesota
from .smallw import Smallw
from .crystm01 import Crystm01
from .opsahlopenflights import OpsahlOpenflights
from .g60 import G60
from .friendster import Friendster
from .livejournallinks import LivejournalLinks
from .soccatster import SocCatster
from .l import L
from .cl1000002d0trial2 import Cl1000002d0Trial2
from .livejournal import Livejournal
from .p2pgnutella24 import P2pGnutella24
from .ex2 import Ex2
from .t03314l import T03314l
from .enron import Enron
from .jagmesh3 import Jagmesh3
from .socfbmississippi66 import SocfbMississippi66
from .keller5 import Keller5
from .csphd import Csphd
from .biogridyeast import BioGridYeast
from .techip import TechIp
from .c1259 import C1259
from .socfbmiddlebury45 import SocfbMiddlebury45
from .soclivemocha import SocLivemocha
from .trec14 import Trec14
from .infecthyper import InfectHyper
from .nr144 import NR144
from .cl1000001d8trial2 import Cl1000001d8Trial2
from .sw10050d3trial1 import Sw10050d3Trial1
from .cadblp2012 import CaDblp2012
from .copresencelh10 import CopresenceLh10
from .ash219 import Ash219
from .cl100001d7trial2 import Cl100001d7Trial2
from .socwikitalkdir import SocWikiTalkDir
from .l9 import L9
from .dbpedia import Dbpedia
from .pkustk09 import Pkustk09
from .caopsahlcollaboration import CaOpsahlCollaboration
from .crplat2 import Crplat2
from .dd6 import Dd6
from .eat import Eat
from .emaildnccorecipient import EmailDncCorecipient
from .aa01 import Aa01
from .adaptive import Adaptive
from .cl10000001d7trial2 import Cl10000001d7Trial2
from .biohsht import BioHsHt
from .roadbelgiumosm import RoadBelgiumOsm
from .ig515 import Ig515
from .caciteseer import CaCiteseer
from .sw10030d1trial3 import Sw10030d1Trial3
from .socblogcatalogasu import SocBlogcatalogAsu
from .comdblp import ComDblp
from .sw10030d2trial2 import Sw10030d2Trial2
from .tf17 import Tf17
from .brock2001 import Brock2001
from .net100 import Net100
from .san400051 import San400051
from .rw5151 import Rw5151
from .egofacebook import EgoFacebook
from .socfbswarthmore42 import SocfbSwarthmore42
from .sw10040d3trial2 import Sw10040d3Trial2
from .webbaidubaikerelated import WebBaiduBaikeRelated
from .socorkutdir import SocOrkutDir
from .sw1000060d3trial2 import Sw1000060d3Trial2
from .webgoogle import WebGoogle
from .flickrlinks import FlickrLinks
from .biogridplant import BioGridPlant
from .ukerbe1 import Ukerbe1
from .socfbucsd34 import SocfbUcsd34
from .cithepth2007 import CitHepth2007
from .alemdar import Alemdar
from .socyoutubesnap import SocYoutubeSnap
from .ragusa18 import Ragusa18
from .biowormnetv3benchmark import BioWormnetV3Benchmark
from .condmat2003 import CondMat2003
from .socfbwashu32 import SocfbWashu32
from .websk2005all import WebSk2005All
from .sw100040d2trial2 import Sw100040d2Trial2
from .c20005 import C20005
from .socfriendster import SocFriendster
from .bioceht import BioCeHt
from .socfbuconn91 import SocfbUconn91
from .g56 import G56
from .trdheim import Trdheim
from .g9 import G9
from .g46 import G46
from .sw100040d1trial3 import Sw100040d1Trial3
from .nr12month1 import NR12month1
from .farm import Farm
from .usroads import Usroads
from .erdos972 import Erdos972
from .hepthnew import HepThNew
from .cegb2919 import Cegb2919
from .biodiseasome import BioDiseasome
from .orkutgroupmemberships import OrkutGroupmemberships
from .sw1000050d2trial3 import Sw1000050d2Trial3
from .pkustk10 import Pkustk10
from .airfoil1 import Airfoil1
from .webit2004all import WebIt2004All
from .sw1000050d1trial2 import Sw1000050d1Trial2
from .cage7 import Cage7
from .techrlcaida import TechRlCaida
from .webberkstan import WebBerkstan
from .blckhole import Blckhole
from .bcsstm24 import Bcsstm24
from .trec4 import Trec4
from .cora import Cora
from .brock8003 import Brock8003
from .socfbsimmons81 import SocfbSimmons81
from .venturilevel3 import Venturilevel3
from .biodrcx import BioDrCx
from .iptrace import IpTrace
from .hugetrace00020 import Hugetrace00020
from .socfbcaltech36 import SocfbCaltech36
from .bcspwr07 import Bcspwr07
from .soctwitterhiggs import SocTwitterHiggs
from .sw100030d3trial2 import Sw100030d3Trial2
from .socfbbanon import SocfbBAnon
from .g24 import G24
from .cfindergoogle import CfinderGoogle
from .socfbwesleyan43 import SocfbWesleyan43
from .san200092 import San200092
from .roadroadnetca import RoadRoadnetCa
from .biomousegene import BioMouseGene
from .sw10030d1trial2 import Sw10030d1Trial2
from .ig514 import Ig514
from .tf16 import Tf16
from .fullb import Fullb
from .sw10030d2trial3 import Sw10030d2Trial3
from .copresenceinvs13 import CopresenceInvs13
from .cl100002d1trial1 import Cl100002d1Trial1
from .socfbbrandeis99 import SocfbBrandeis99
from .biodmlc import BioDmLc
from .sls import Sls
from .johnson1624 import Johnson1624
from .citeulikeut import CiteulikeUt
from .cl10000001d7trial3 import Cl10000001d7Trial3
from .amazon2008 import Amazon2008
from .socfbtexas84 import SocfbTexas84
from .dbpediawriter import DbpediaWriter
from .nr3dtube import NR3dtube
from .rw136 import Rw136
from .cl10001d8trial1 import Cl10001d8Trial1
from .cage import Cage
from .hospitalwardproximity import HospitalWardProximity
from .socfbdartmouth6 import SocfbDartmouth6
from .ford2 import Ford2
from .techas735 import TechAs735
from .maayanpdzbase import MaayanPdzbase
from .maayanfoodweb import MaayanFoodweb
from .sw1000060d3trial3 import Sw1000060d3Trial3
from .socfbuc33 import SocfbUc33
from .sw10040d3trial3 import Sw10040d3Trial3
from .misclesmis import MiscLesmis
from .biocelegansneural import BioCelegansneural
from .orkut import Orkut
from .pkustk11 import Pkustk11
from .sw1000050d2trial2 import Sw1000050d2Trial2
from .pkustk01 import Pkustk01
from .cti import Cti
from .cage6 import Cage6
from .soctwitter2010 import SocTwitter2010
from .sw1000050d1trial3 import Sw1000050d1Trial3
from .techroutersrf import TechRoutersRf
from .scpwtk import ScPwtk
from .phat7001 import PHat7001
from .power import Power
from .citeseer import Citeseer
from .sw100040d2trial3 import Sw100040d2Trial3
from .cl100001d9trial1 import Cl100001d9Trial1
from .g47 import G47
from .aveswildbirdnetwork import AvesWildbirdNetwork
from .sw100040d1trial2 import Sw100040d1Trial2
from .g8 import G8
from .g25 import G25
from .sw100030d3trial3 import Sw100030d3Trial3
from .wikisignedk2 import WikisignedK2
from .socljournal2008 import SocLjournal2008
from .g35 import G35
from .bcspwr06 import Bcspwr06
from .copresencesfhh import CopresenceSfhh
from .dbpedialink import DbpediaLink
from .auto import Auto
from .san200093 import San200093
from .hugetric00020 import Hugetric00020
from .trec5 import Trec5
from .socfbvanderbilt48 import SocfbVanderbilt48
from .bcsstm25 import Bcsstm25
from .nr162bit import NR162bit
from .socfbemory27 import SocfbEmory27
from .socfbucf52 import SocfbUcf52
from .socfbcal65 import SocfbCal65
from .odepb400 import Odepb400
from .techarenaspgp import TechArenasPgp
from .biocelegansdir import BioCelegansDir
from .cl10002d0trial1 import Cl10002d0Trial1
from .brock8002 import Brock8002
from .cegb2802 import Cegb2802
from .socflixster import SocFlixster
from .socfbrice31 import SocfbRice31
from .ash85 import Ash85
from .socfbpenn94 import SocfbPenn94
from .cage11 import Cage11
from .fa import Fa
from .sw10060d2trial1 import Sw10060d2Trial1
from .sw1000040d2trial1 import Sw1000040d2Trial1
from .gottronexcellent import GottronExcellent
from .sw100050d1trial1 import Sw100050d1Trial1
from .socwikivote import SocWikiVote
from .visualizeus import VisualizeUs
from .pgpgiantcompo import Pgpgiantcompo
from .socbrightkite import SocBrightkite
from .ecomangwet import EcoMangwet
from .sockarate import SocKarate
from .m3plates import M3plates
from .brock4004 import Brock4004
from .soclivejournalusergroups import SocLivejournalUserGroups
from .socstudentcoop import SocStudentCoop
from .g61 import G61
from .wbedu import WbEdu
from .cl1000002d0trial3 import Cl1000002d0Trial3
from .petsterhamster import PetsterHamster
from .screl9 import ScRel9
from .phat5002 import PHat5002
from .stufe import Stufe
from .cl10000001d9trial1 import Cl10000001d9Trial1
from .polbooks import Polbooks
from .ramage02 import Ramage02
from .socflickrasu import SocFlickrAsu
from .sw1000030d3trial1 import Sw1000030d3Trial1
from .cahollywood2009 import CaHollywood2009
from .webnotredame import WebNotredame
from .camathscinet import CaMathscinet
from .imdb import IMDB
from .air03 import Air03
from .webwebbase2001 import WebWebbase2001
from .bnmacaquerhesusbrain import BNMacaqueRhesusBrain
from .lasagnespanishbook import LasagneSpanishbook
from .keller4 import Keller4
from .proteinsall import ProteinsAll
from .cfat5005 import CFat5005
from .scmsdoor import ScMsdoor
from .techwhois import TechWhois
from .lop163 import Lop163
from .net75 import Net75
from .adjnoun import Adjnoun
from .p2pgnutella25 import P2pGnutella25
from .socfbvillanova62 import SocfbVillanova62
from .sw1000060d3l5 import Sw1000060d3L5
from .astroph import AstroPh
from .jagmesh2 import Jagmesh2
from .aa6 import Aa6
from .celegansneural import Celegansneural
from .hamming82 import Hamming82
from .powereris1176 import PowerEris1176
from .webclueweb0950m import WebClueweb0950m
from .pkustk08 import Pkustk08
from .sw100060d3trial1 import Sw100060d3Trial1
from .oregon2 import Oregon2
from .socflickr import SocFlickr
from .egotwitter import EgoTwitter
from .fcondp2 import Fcondp2
from .biogridmouse import BioGridMouse
from .cl10000002d1trial1 import Cl10000002d1Trial1
from .kl02 import Kl02
from .socfbuillinois import SocfbUillinois
from .socfbucla26 import SocfbUcla26
from .socfbjmu79 import SocfbJmu79
from .df2177 import Df2177
from .webuk2002all import WebUk2002All
from .uk import Uk
from .cl1000001d8trial3 import Cl1000001d8Trial3
from .socfbamherst41 import SocfbAmherst41
from .socflickrund import SocFlickrUnd
from .socfbhaverford76 import SocfbHaverford76
from .libimseti import Libimseti
from .cl100001d7trial3 import Cl100001d7Trial3
from .sanr40007 import Sanr40007
from .scshipsec5 import ScShipsec5
from .socfbrochester38 import SocfbRochester38
from .g1 import G1

__all__ = [
	"C5009", "OpsahlSouthernwomen", "SocfbNorthwestern25", "Gen400P0965", "Gen400P0975",
	"San400073", "G29", "Cl10002d1Trial1", "G39", "SocfbUsc35", "Jagmesh7",
	"Aa3", "ZhishiZhwikiInternallink", "Sw100030d2Trial3", "TechAsCaida", "ScLdoor",
	"Trec9", "SocfbBowdoin47", "Bcsstm39", "Dsjc5005", "P2pGnutella30", "Tube2",
	"Email", "NR208bit", "Ex6", "Sw100030d1Trial2", "Sw100040d3Trial3", "Cl100001d8Trial1",
	"MannA9", "Hamming104", "BioScHt", "InfEuroroad", "Cl1000001d7Trial1",
	"MannA81", "Tsyl201", "G4", "Sw1000050d3Trial2", "YahooMsg", "Skirt", "Net150",
	"DbpediaTeam", "PowerBcspwr09", "Dictionary28", "Trec10", "Barth5", "Foldoc",
	"Sw10040d1Trial2", "Bcsstm06", "Sw1000060d1Trial2", "Sw10040d2Trial3",
	"EcoStmarks", "Sw1000060d2Trial3", "Patentcite", "Johnson3224", "EmailEuall",
	"SocSinaweibo", "Cage14", "G16", "Cl10001d9Trial1", "ActorCollaboration",
	"Kohonen", "SocHighschoolMoreno", "Biplane9", "Brock4001", "Plc4030L5",
	"SocfbMsu24", "SocfbJohnshopkins55", "Ljournal2008", "Ig518", "G64", "Rajat08",
	"Finance256", "SocLivejournal", "Air06", "Cl100002d0Trial1", "FeBody",
	"Bcsstk31", "SocAnuResidence", "Engine", "Sw10030d3Trial3", "Cage3", "CaHepth",
	"FoodwebBaydry", "SocfbOberlin44", "SocTwitter", "Cl1000001d9Trial3", "MiscImdbBi",
	"Pkustk04", "Pkustk14", "BNHumanJung", "Sw10050d1Trial1", "BioScTs", "G52",
	"Sw100060d2Trial1", "DbpediaRecordlabel", "G42", "PowerBcspwr10", "Cl10000002d0Trial1",
	"SocfbMaryland58", "Rw496", "Se", "Cl10k1d8L5", "RoadnetPa", "Bcspwr03",
	"SocDelicious", "G30", "RoadNetherlandsOsm", "Dolphins", "InfRoadnetPa",
	"SocfbBc17", "Pcrystk03", "Struct3", "TechArenasMeta", "Bcsstm20", "Patents",
	"AffFlickrUserGroups", "Ash958", "PHat15003", "Tf13", "Cl10000001d8Trial1",
	"SocfbHoward90", "Enzymes8", "CFat2002", "Rajat01", "Sw1000030d2Trial1",
	"Pds10", "SocDolphins", "Ig511", "Lshp1561", "Ash292", "SocfbAmerican75",
	"SocfbMit", "Gupta1", "SocfbHamilton46", "San200072", "Dsjc10005", "Cl1000002d1Trial3",
	"P2pGnutella06", "Packing500x100x100B050", "BioCeGt", "ActorMovie", "MiscJungCodeDep",
	"PHat3003", "SocSlashdot", "Data", "Ash331", "Uk2002", "Erdos992", "Erdos982",
	"Ig58", "PHat10002", "Uspowergrid", "AffGithubUser2project", "RtRetweet",
	"CopresenceThiers13", "Chesapeake", "Sstmodel", "Sw1000040d3Trial1", "Johnson844",
	"Sw10060d3Trial1", "Cl10001d7Trial3", "AffAmazonCopurchases", "CaMathscinetDir",
	"G43", "G53", "AffDigg", "Sw100060d1Trial1", "CaCondmat", "DblpCite", "Cl1000001d9Trial2",
	"Sw10050d2Trial1", "Amazon0302", "Amazon0312", "TechP2pGnutella", "FbCmuCarnegie49",
	"BioCeCx", "Barth", "Pkustk05", "Srb1", "WebIndochina2004All", "Pcrystk02",
	"SocSlashdotTrustAll", "MaayanFigeys", "BioCelegans", "As735", "Bcsstm21",
	"AsSkitter", "Hollywood2009", "CaErdos992", "Dd497", "ArenasMeta", "SocfbFsu53",
	"CaNetscience", "SocTwitterFollows", "AvesSparrowSocial", "SocfbCmu", "ScPkustk11",
	"WebEpa", "Bcspwr02", "G31", "Chem97zt", "TechInternetAs", "SocfbWake73",
	"ZhishiBaiduInternallink", "Bfly", "AvesWeaverSocial", "DbpediaCountry",
	"Net25", "BioHumanGene1", "Cl1000002d1Trial2", "ZhishiHudongInternallink",
	"Bcsstk29", "BioCePg", "SocPokec", "Us04", "Sw1000030d1Trial1", "Copter2",
	"SocfbMichigan23", "Brock2004", "Tf12", "PHat15002", "YoutubeGroupmemberships",
	"Connectus", "Ig510", "RoadGermanyOsm", "Rajat10", "BioHsCx", "EcoFoodwebBaywet",
	"Bas1lp", "Ig59", "RtRetweetCrawl", "SocfbWisconsin87", "Glossgt", "Cl10001d7Trial2",
	"SocGooglePlus", "PHat10003", "Lshp2233", "Pfinan512", "MaayanFaa", "RoadnetTx",
	"Sw100050d3Trial1", "CaAminer", "SocfbTexas80", "Sw100030d2Trial2", "ZhishiBaiduRelatedpages",
	"WbCsStanford", "Jagmesh6", "Sw100030d1Trial3", "P2pGnutella31", "Reactome",
	"Github", "SocfbBerkeley13", "ZhishiHudongRelatedpages", "Trec8", "San400072",
	"WebItalycnr2000", "WebStanford", "WebIndochina2004", "SocfbNortheastern19",
	"Stanford", "CFat5001", "SocSignBitcoinotc", "Flickr", "G38", "Sw1000050d3Trial3",
	"G5", "ScShipsec1", "SocfbColgate88", "Arabic2005", "Ccc", "Barth4", "C20009",
	"SocLastfm", "Trec11", "SocBuzznet", "Usroads48", "BioGridWorm", "Sw100040d3Trial2",
	"SocfbNotredame57", "Epa", "ErMd", "G17", "SocfbIndiana69", "Cvxbqp1",
	"Sw1000060d1Trial3", "Hugebubbles00010", "Sw10040d1Trial3", "Hugebubbles00000",
	"SocfbColumbia2", "Cage15", "Sw1000060d2Trial2", "RoadUsroads", "SocAcademia",
	"Sw10040d2Trial2", "Karate", "Sw10030d3Trial2", "Sanr20009", "Bcsstk30",
	"Cl10m1d8L5", "WordnetWords", "MiscFootball", "EgoGplus", "SocfbUnc28",
	"WebEdu", "CaGrqc", "BioWormnetV3", "Mri1", "Rajat09", "G65", "Grid1",
	"Hamming62", "Gearbox", "Bcsstm23", "TechAsCaida20071105", "WebBerkstanDir",
	"SocPokecRelationships", "SocAdvogato", "RoadGreatBritainOsm", "Brock8004",
	"SocfbStanford3", "RoadMinnesota", "WebSpamDetection", "Bcspwr10", "G23",
	"ScPkustk13", "Chem97ztz", "EcoEverglades", "SocfbKonect", "YoutubeLinks",
	"Sphere3", "EmailUniv", "AsCaida20071105", "Cl10000002d0Trial2", "Sw100060d1Trial3",
	"Lshp1270", "G51", "Sw100060d2Trial2", "PetsterCarnivore", "G41", "Pkustk07",
	"Sw10050d1Trial2", "DbpediaOccupation", "SocfbMaine59", "SocfbUillinois20",
	"SocfbCarnegie49", "TechP2p", "Sw10050d2Trial3", "Football", "PHat10001",
	"Sw1000040d3Trial2", "C10009", "Sw10060d3Trial2", "Erdos991", "Dd199",
	"WebWikipedia2009", "Erdos981", "WebUk2005", "SocfbBaylor93", "Fe4elt2",
	"Abb313", "TrecWt10g", "SocfbReed98", "Sw100050d3Trial3", "SocfbNyu9",
	"P2pGnutella05", "EcoFoodwebBaydry", "Gupta2", "San200071", "Advogato",
	"SocfbBu10", "CaCoauthorsDblp", "CFat2001", "RtTwitterCopen", "RoadItalyOsm",
	"BioGridFruitfly", "SocfbDuke14", "Sw1000030d2Trial2", "Rajat02", "Ig512",
	"OpsahlUsairport", "SocfbUsf51", "SocGplus", "Tf10", "Troll", "Cl10000001d8Trial2",
	"TechPgp", "Sw1000030d1Trial3", "CopresenceInvs15", "Trec13", "WebGoogleDir",
	"AsCaida", "Cca", "FeTooth", "Sw1000050d3Trial1", "G7", "G48", "SocfbOr",
	"SocfbUc61", "G58", "CaAstroph", "Cl1000001d7Trial2", "BioDmHt", "SocfbUpenn7",
	"EmailEu", "EcoFlorida", "Cage9", "Cl100001d8Trial2", "DbpediaGenre", "Tube1",
	"Ex5", "Sw100030d1Trial1", "Jagmesh4", "NR145bit", "Journals", "Hamming84",
	"HepTh", "Lock3491", "Eva", "Cl10002d1Trial2", "Geom", "Bcspwr09", "SocfbTufts18",
	"SocTwitterMpiSws", "SocTwitterFollowsMun", "SocfbMu78", "Cl100002d0Trial2",
	"Bcsstk32", "RoadnetCa", "AffWikiWordbypage", "As20000102", "Cnr2000",
	"InfRoadnetCa", "Jgl009", "Air05", "Rail2586", "Pwt", "SocEpinions1", "G67",
	"Tf19", "Pattern1", "SocfbUva16", "Nasa4704", "TechCaidarouterlevel", "Cs4",
	"Ash608", "Hugetric00000", "Hugetric00010", "BioYeastProteinInter", "SocFirmHiTech",
	"G15", "SocOrkut", "MiscReuters911", "Cl10001d9Trial2", "In2004", "Brock4002",
	"Netz4504", "PowerUsGrid", "RoadEuroroad", "Bcsstm05", "Ragusa16", "OpsahlPowergrid",
	"SocfbUsfca72", "Sw10040d1Trial1", "SocfbOklahoma97", "Sw1000060d1Trial1",
	"SocDouban", "SocfbBucknell39", "Cl1000001d7Trial3", "CaActorCollaboration",
	"NR3elt", "WebSk2005", "Cl100001d8Trial3", "Sw100040d3Trial1", "Cage8",
	"CitPatent", "BioHsLc", "Trec12", "Caidarouterlevel", "DbpediaLocation",
	"G59", "G49", "G6", "It2004", "CFat5002", "Bcspwr08", "Cl10002d1Trial3",
	"San400071", "SocfbUf21", "SlashdotZoo", "Sw1000060d3L2", "Ex4", "OrkutLinks",
	"Ibm32", "Appu", "Sw100030d2Trial1", "SocDogster", "Jagmesh5", "Grid2",
	"G66", "Mri2", "Diag", "SocfbUchicago30", "SocfbWilliams40", "Actor", "SocfbBrown11",
	"T520", "Tf18", "BioCeLc", "Sw10030d3Trial1", "T60k", "Bcsstk33", "Crack",
	"Cl100002d0Trial3", "SocfbSanta74", "SocfbCornell5", "Air04", "PetsterFriendshipsDog",
	"Sw1000060d2Trial1", "BioGridFissionYeast", "Sw10040d2Trial1", "Pct20stif",
	"ComYoutube", "PetsterFriendshipsCat", "SocfbHarvard1", "Hugetrace00000",
	"Brock4003", "Polblogs", "Hugetrace00010", "Cl10001d9Trial3", "Roget",
	"G14", "WebPolblogs", "ArenasPgp", "Netscience", "SocfbVirginia63", "Plc6030L2",
	"Gene", "FoodwebBaywet", "G22", "Indochina2004", "Bcspwr01", "BioGridHuman",
	"Coauthorsciteseer", "SocBlogcatalog", "BioScCc", "SocFoursquare", "Bcsstm22",
	"Qa8fm", "SocfbWellesley22", "Halfb", "ComAmazon", "RoadRoadUsa", "SocfbUconn",
	"EmailEnronOnly", "UcidataGama", "Dd68", "Sw10050d1Trial3", "SocfbUga50",
	"Pkustk06", "Cl1000001d9Trial1", "Sw10050d2Trial2", "SocYoutube", "Stufe10",
	"Sw100060d1Trial2", "Cl10000002d0Trial3", "Sphere2", "Enzymes118", "SocfbIndiana",
	"Opt1", "G40", "Sw100060d2Trial3", "G50", "EconPsmigr2", "Sw100050d3Trial2",
	"SocfbMit8", "P2pGnutella04", "DblpAuthor", "Citationciteseer", "Cl10001d7Trial1",
	"Sw10060d3Trial3", "Sw1000040d3Trial3", "InfOpenflights", "NR08blocks",
	"Ig513", "Channel500x100x100B050", "TechAsCaida2007", "Sw1000030d2Trial3",
	"Twitter", "Johnson824", "Cl10000001d8Trial3", "Sw1000030d1Trial2", "Copter1",
	"PHat15001", "Tf11", "Dixmaanl", "BioHumanGene2", "FsFa", "Cl1000002d1Trial1",
	"Wave", "Gupta3", "Jgl011", "Dd242", "FeSphere", "Bcsstm08", "SocfbNipsEgo",
	"Net41", "TechArenasJazz", "Cl10001d8Trial3", "SocfbVermont70", "SocDigg",
	"Sw10040d3Trial1", "Uk2005", "InfPower", "Sw1000060d3Trial1", "WebUk2005All",
	"Lock1074", "PetsterFriendshipsHamster", "SocfbRutgers89", "Cl100002d1Trial3",
	"RoadAsiaOsm", "Sw10030d2Trial1", "CFat50010", "Brock2002", "Tf14", "Rajat06",
	"Ig516", "As22july06", "CFat2005", "WebkbWisc", "Cl10000001d7Trial1", "SocfbUcsc68",
	"Shock9", "San200091", "CondMat", "Cities", "Rail4284", "SocfbYale4", "Lshp3466",
	"S4dkt3m2", "Debr", "Bcspwr04", "G37", "G27", "Sw100030d3Trial1", "MaayanStelzl",
	"Struct4", "SocfbMich67", "Cl10002d0Trial3", "Kleemin", "Jagmesh9", "Lp1",
	"Trec7", "PHat7003", "AffWikiEnArticleCat", "Cage4", "Sw1000050d1Trial1",
	"SocfbUf", "Erdos971", "Pkustk03", "Pkustk13", "ScNasasrb", "G55", "G45",
	"California", "RoadLuxembourgOsm", "Cl100001d9Trial3", "Sw100040d2Trial1",
	"CaCsphd", "UcidataZachary", "Cl1000002d0Trial1", "SocPhysicians", "SocLivejournal1",
	"Crystm02", "G63", "NR130bit", "SocfbGwu54", "Dblp2010", "Hamming64", "Amazon0601",
	"SocLocBrightkite", "EmailEnronLarge", "C40005", "Sw1000030d3Trial3", "SocThemarker",
	"InfUsair97", "RoadRoadnetPa", "Pli", "MaayanVidal", "SocfbUcla", "SocTribes",
	"Cl10000001d9Trial3", "SocfbAuburn71", "Webbase1m", "Amazon0505", "Sw1000040d2Trial3",
	"P2pGnutella08", "Sw10060d2Trial3", "Bcsstm11", "CoPapersDblp", "SfhhConfSensor",
	"Sw1000040d1Trial2", "Cage13", "Enzymes296", "Sw10060d1Trial2", "Epinions",
	"Ig56", "Rgg010", "SocfbTennessee95", "Sw100050d2Trial2", "Coater1", "Sw100050d1Trial3",
	"FlickrGroupmemberships", "Cl10000002d1Trial3", "Lesmis", "SocEpinions",
	"G3rmt3m3", "InfectDublin", "Sw100060d3Trial3", "FeOcean", "Gen200P0955",
	"G3", "Usair97", "C2509", "Cl100001d7Trial1", "SocfbTemple83", "Sanr40005",
	"Lederberg", "Lshp1882", "Lock2232", "WebHudong", "Cl1000001d8Trial1",
	"Sw10050d3Trial2", "Internet", "DbpediaProducer", "SocHamsterster", "Net125",
	"SocfbUciUni", "Coauthorsdblp", "Keller6", "FbMessages", "SocfbVassar85",
	"SocAnybeat", "Brack2", "SocfbTrinity100", "Aa4", "RtHiggs", "Ex1", "Sw1000030d3Trial2",
	"SocSlashdotZoo", "San400091", "PHat5001", "SocfbPrinceton12", "Cl10000001d9Trial2",
	"ContiguousUsa", "Cegb3024", "CitPatents", "BioCeGn", "San1000", "SocfbAAnon",
	"Lshp2614", "G62", "Crystm03", "SocfbSyracuse56", "Sw100050d2Trial3", "G10",
	"Divorce", "RoadChesapeake", "Curtis54", "Ig57", "Flickredges", "Sw100050d1Trial2",
	"SocSlashdot0811", "Linux", "Sw10060d2Trial2", "P2pGnutella09", "Sw1000040d2Trial2",
	"Sw10060d1Trial3", "Enzymes297", "Cage12", "AffOrkutUser2groups", "Sw1000040d1Trial3",
	"BNMouseRetina", "LivejournalGroupmemberships", "WebIt2004", "SocfbUc64",
	"G2", "BioDmCx", "Sw10050d3Trial3", "CaDblp2010", "SocfbPepperdine86",
	"WikiEnCat", "Reuters911", "Cl10000002d1Trial2", "WebWikiChInternal", "Hamming102",
	"Crew1", "Eris1176", "SocfbUcsb37", "BNFlyDrosophilaMedulla", "Sw100060d3Trial2",
	"Gen200P0944", "Oregon1", "Ins2", "Sk2005", "Aa5", "Jagmesh1", "SocGowalla",
	"Tomographic1", "Jazz", "CaImdb", "Lshp3025", "Dd687", "InfContiguousUsa",
	"Nw14", "ArenasJazz", "Cyl6", "Scimet", "SocfbSmith60", "Gen400P0955",
	"RoadUsroads48", "Bcsstm19", "Net50", "Bcsstm09", "M14b", "Mip1", "Ford1",
	"Dd21", "BioDmela", "Smagri", "Cl10001d8Trial2", "Harvard500", "Gent113",
	"Dd349", "Aa03", "TechAs22july06", "Sanr20007", "Brock2003", "Enzymes123",
	"Tf15", "BioScLc", "SocSlashdot0902", "Cl100002d1Trial2", "Wing", "Sw10030d1Trial1",
	"NR192bit", "Ig517", "Rajat07", "Eu2005", "Jagmesh8", "Brock8001", "Erdos02",
	"CoPapersCiteseer", "Cl10002d0Trial2", "Bcsstm26", "Trec6", "TechAsSkitter",
	"WebArabic2005", "CitDblp", "WikiTalk", "Lshp1009", "SocfbLehigh96", "AffDbpediaUsers2country",
	"SocfbTulane29", "MannA45", "G26", "NR598a", "DbpediaAll", "Bcspwr05",
	"Cegb3306", "G36", "Pf2177", "MannA27", "SocLivejournal07", "SocfbGeorgetown15",
	"Sw100040d1Trial1", "G44", "G54", "Odlis", "Cl100001d9Trial2", "Cage5",
	"PHat7002", "DbpediaStarring", "Sw1000050d2Trial1", "WebSpam", "Pkustk12",
	"WebBaiduBaike", "Pkustk02", "WebClueweb09", "WebCc12Payleveldomain", "SocfbBingham82",
	"BioYeast", "CiteulikeUi", "CiteulikeTi", "Lpl1", "BioScGt", "Sw100050d2Trial1",
	"Coater2", "CopresenceLyonschool", "Cage10", "Sw1000040d1Trial1", "Enzymes295",
	"Sw10060d1Trial1", "CaHepph", "WebWebbase2001All", "Bcsstm02", "NR176bit",
	"EmailEnron", "PHat5003", "PrimarySchoolProximity", "SocfbWilliam77", "Air02",
	"SocfbUmass92", "Minnesota", "Smallw", "Crystm01", "OpsahlOpenflights",
	"G60", "Friendster", "LivejournalLinks", "SocCatster", "L", "Cl1000002d0Trial2",
	"Livejournal", "P2pGnutella24", "Ex2", "T03314l", "Enron", "Jagmesh3",
	"SocfbMississippi66", "Keller5", "Csphd", "BioGridYeast", "TechIp", "C1259",
	"SocfbMiddlebury45", "SocLivemocha", "Trec14", "InfectHyper", "NR144",
	"Cl1000001d8Trial2", "Sw10050d3Trial1", "CaDblp2012", "CopresenceLh10",
	"Ash219", "Cl100001d7Trial2", "SocWikiTalkDir", "L9", "Dbpedia", "Pkustk09",
	"CaOpsahlCollaboration", "Crplat2", "Dd6", "Eat", "EmailDncCorecipient",
	"Aa01", "Adaptive", "Cl10000001d7Trial2", "BioHsHt", "RoadBelgiumOsm",
	"Ig515", "CaCiteseer", "Sw10030d1Trial3", "SocBlogcatalogAsu", "ComDblp",
	"Sw10030d2Trial2", "Tf17", "Brock2001", "Net100", "San400051", "Rw5151",
	"EgoFacebook", "SocfbSwarthmore42", "Sw10040d3Trial2", "WebBaiduBaikeRelated",
	"SocOrkutDir", "Sw1000060d3Trial2", "WebGoogle", "FlickrLinks", "BioGridPlant",
	"Ukerbe1", "SocfbUcsd34", "CitHepth2007", "Alemdar", "SocYoutubeSnap",
	"Ragusa18", "BioWormnetV3Benchmark", "CondMat2003", "SocfbWashu32", "WebSk2005All",
	"Sw100040d2Trial2", "C20005", "SocFriendster", "BioCeHt", "SocfbUconn91",
	"G56", "Trdheim", "G9", "G46", "Sw100040d1Trial3", "NR12month1", "Farm",
	"Usroads", "Erdos972", "HepThNew", "Cegb2919", "BioDiseasome", "OrkutGroupmemberships",
	"Sw1000050d2Trial3", "Pkustk10", "Airfoil1", "WebIt2004All", "Sw1000050d1Trial2",
	"Cage7", "TechRlCaida", "WebBerkstan", "Blckhole", "Bcsstm24", "Trec4",
	"Cora", "Brock8003", "SocfbSimmons81", "Venturilevel3", "BioDrCx", "IpTrace",
	"Hugetrace00020", "SocfbCaltech36", "Bcspwr07", "SocTwitterHiggs", "Sw100030d3Trial2",
	"SocfbBAnon", "G24", "CfinderGoogle", "SocfbWesleyan43", "San200092", "RoadRoadnetCa",
	"BioMouseGene", "Sw10030d1Trial2", "Ig514", "Tf16", "Fullb", "Sw10030d2Trial3",
	"CopresenceInvs13", "Cl100002d1Trial1", "SocfbBrandeis99", "BioDmLc", "Sls",
	"Johnson1624", "CiteulikeUt", "Cl10000001d7Trial3", "Amazon2008", "SocfbTexas84",
	"DbpediaWriter", "NR3dtube", "Rw136", "Cl10001d8Trial1", "Cage", "HospitalWardProximity",
	"SocfbDartmouth6", "Ford2", "TechAs735", "MaayanPdzbase", "MaayanFoodweb",
	"Sw1000060d3Trial3", "SocfbUc33", "Sw10040d3Trial3", "MiscLesmis", "BioCelegansneural",
	"Orkut", "Pkustk11", "Sw1000050d2Trial2", "Pkustk01", "Cti", "Cage6", "SocTwitter2010",
	"Sw1000050d1Trial3", "TechRoutersRf", "ScPwtk", "PHat7001", "Power", "Citeseer",
	"Sw100040d2Trial3", "Cl100001d9Trial1", "G47", "AvesWildbirdNetwork", "Sw100040d1Trial2",
	"G8", "G25", "Sw100030d3Trial3", "WikisignedK2", "SocLjournal2008", "G35",
	"Bcspwr06", "CopresenceSfhh", "DbpediaLink", "Auto", "San200093", "Hugetric00020",
	"Trec5", "SocfbVanderbilt48", "Bcsstm25", "NR162bit", "SocfbEmory27", "SocfbUcf52",
	"SocfbCal65", "Odepb400", "TechArenasPgp", "BioCelegansDir", "Cl10002d0Trial1",
	"Brock8002", "Cegb2802", "SocFlixster", "SocfbRice31", "Ash85", "SocfbPenn94",
	"Cage11", "Fa", "Sw10060d2Trial1", "Sw1000040d2Trial1", "GottronExcellent",
	"Sw100050d1Trial1", "SocWikiVote", "VisualizeUs", "Pgpgiantcompo", "SocBrightkite",
	"EcoMangwet", "SocKarate", "M3plates", "Brock4004", "SocLivejournalUserGroups",
	"SocStudentCoop", "G61", "WbEdu", "Cl1000002d0Trial3", "PetsterHamster",
	"ScRel9", "PHat5002", "Stufe", "Cl10000001d9Trial1", "Polbooks", "Ramage02",
	"SocFlickrAsu", "Sw1000030d3Trial1", "CaHollywood2009", "WebNotredame",
	"CaMathscinet", "IMDB", "Air03", "WebWebbase2001", "BNMacaqueRhesusBrain",
	"LasagneSpanishbook", "Keller4", "ProteinsAll", "CFat5005", "ScMsdoor",
	"TechWhois", "Lop163", "Net75", "Adjnoun", "P2pGnutella25", "SocfbVillanova62",
	"Sw1000060d3L5", "AstroPh", "Jagmesh2", "Aa6", "Celegansneural", "Hamming82",
	"PowerEris1176", "WebClueweb0950m", "Pkustk08", "Sw100060d3Trial1", "Oregon2",
	"SocFlickr", "EgoTwitter", "Fcondp2", "BioGridMouse", "Cl10000002d1Trial1",
	"Kl02", "SocfbUillinois", "SocfbUcla26", "SocfbJmu79", "Df2177", "WebUk2002All",
	"Uk", "Cl1000001d8Trial3", "SocfbAmherst41", "SocFlickrUnd", "SocfbHaverford76",
	"Libimseti", "Cl100001d7Trial3", "Sanr40007", "ScShipsec5", "SocfbRochester38",
	"G1",
]


"""Methods to parse the incidence matrix from LINQS."""
import re
import os
import pandas as pd
import numpy as np
from typing import Tuple
from ensmallen import Graph
from tqdm.auto import tqdm


def get_words_data(graph: Graph) -> Tuple[Graph, pd.DataFrame]:
    """Return dataframe with words features.

    Parameters
    --------------------
    graph: Graph,
        Graph containing the words features to be extracted.

    Returns
    --------------------
    Tuple containing:
        - Provided graph without the Word nodes.
        - Pandas DataFrame with words features as columns and nodes as rows.
    """
    word_node_type = graph.get_node_type_id_from_node_type_name("Word")
    # Extracting node features
    node_features = pd.DataFrame({
        node_name: {
            graph.get_node_name_from_node_id(dst): graph.get_edge_weight_from_node_ids(src, dst) if graph.has_edge_weights() else 1.0
            for dst in graph.get_neighbour_node_ids_from_node_id(src)
        }
        for src, node_name in enumerate(tqdm(graph.get_node_names(), desc="Extracting words features"))
        if word_node_type in graph.get_node_type_ids_from_node_id(src)
    }).fillna(0.0)
    # Filtering graph
    filtered_graph = graph.filter_from_names(
        node_type_name_to_filter=["Word"]
    ).remove_edge_weights().remove_edge_types()
    # Aligning node features with filtered graph node names.
    node_features = node_features.loc[filtered_graph.get_node_names()]
    # Returning elaborared graph and node features.
    return (filtered_graph, node_features)


def parse_linqs_pubmed_incidence_matrix(
    cites_path: str,
    content_path: str,
    edge_path: str,
    node_path: str
):
    """Parse PubMed incidence matrix and generates proper edge list and node file.

    Parameters
    -------------------
    cites_path: str,
        Path from where to load the cites file.
    content_path: str,
        Path from where to load the content file.
    edge_path: str,
        Path where to store the edge list.
    node_path: str,
        Path where to store the node list.
    """
    # If the file has already been created, we skip
    # this preprocessing.
    if os.path.exists(node_path) and os.path.exists(edge_path):
        return
    # Creating directories
    os.makedirs(os.path.dirname(edge_path), exist_ok=True)
    os.makedirs(os.path.dirname(node_path), exist_ok=True)
    # Loading data
    with open(content_path) as f:
        content = f.read()
    with open(cites_path) as f:
        cites = f.read()

    separator = "\t"

    edge_list_file = open(edge_path, "w")
    node_list_file = open(node_path, "w")

    unique_words = set()
    edge_regex = re.compile(r"paper:(\d+)")
    node_regex = re.compile(r"(\d+)\s+label=(\d+)")
    word_regex = re.compile(r"w-(\w+)=(\S+)")

    labels = [
        "Diabetes Mellitus, Experimental",
        "Diabetes Mellitus Type 1",
        "Diabetes Mellitus Type 2"
    ]

    edge_list_file.write(
        separator.join(("subject", "object", "edge_type", "weight")) + "\n"
    )
    node_list_file.write(separator.join(("id", "node_type")) + "\n")

    for line in cites.split("\n")[2:-1]:
        edge = re.findall(edge_regex, line)
        if len(edge) != 2:
            continue
        # Writing the edges between papers and papers
        edge_list_file.write(separator.join((*edge, "Paper2Paper", "")) + "\n")

    for line in content.split("\n")[2:]:
        vals = re.findall(node_regex, line)
        if len(vals) != 1:
            break

        src, label = vals[0]
        # Writing node and its node type to the node list.
        node_list_file.write(separator.join(
            (src, labels[int(label)-1])) + "\n")

        # Writing the edges between papers and words
        for (word, weight) in re.findall(word_regex, line):
            edge_list_file.write(
                separator.join((src, word, "Paper2Word", weight)) + "\n")
            # Add word to the unique words set
            unique_words.add(word)

    # Writing the nodes representing words
    for word in unique_words:
        node_list_file.write(separator.join((word, "Word")) + "\n")

    edge_list_file.close()
    node_list_file.close()


def parse_linqs_incidence_matrix(
    cites_path: str,
    content_path: str,
    edge_path: str,
    node_path: str
):
    """Parse Cora and Citeseer incidence matrix and generates proper edge list and node file.

    Parameters
    -------------------
    cites_path: str,
        Path from where to load the cites file.
    content_path: str,
        Path from where to load the content file.
    edge_path: str,
        Path where to store the edge list.
    node_path: str,
        Path where to store the node list.
    """
    # If the file has already been created, we skip
    # this preprocessing.
    if os.path.exists(node_path) and os.path.exists(edge_path):
        return
    # Creating directories
    os.makedirs(os.path.dirname(edge_path), exist_ok=True)
    os.makedirs(os.path.dirname(node_path), exist_ok=True)
    # Loading the content file (incidence matrix)
    content = pd.read_csv(
        content_path,
        sep="\t",
        header=None,
        index_col=0,
        dtype=str
    )
    # Loading the citations file (edge list)
    cities = pd.read_csv(
        cites_path,
        sep="\t",
        header=None,
        dtype=str
    )
    # Standardizing dataframe
    cities.columns = ["subject", "object"]
    cities["edge_type"] = "Paper2Paper"
    # Extract labels from incidence matrix
    labels = content[content.columns[-1]]
    # Removing labels column
    content.drop(columns=content.columns[-1], inplace=True)
    # Converting incidence matrix to edge list
    node_indices, word_indices = np.where(content.values.astype(int) == 1)
    # Create words vector
    words = np.array([
        "word_{}".format(word_id)
        for word_id in np.arange(max(word_indices)+1)
    ])
    # Create the node list
    node_list = pd.concat([
        pd.DataFrame({
            "id": content.index.astype(str),
            "node_type": labels
        }),
        pd.DataFrame({
            "id": words,
            "node_type": "Word"
        }),
        pd.DataFrame({
            "id": list(
                set(cities[["subject", "object"]].values.flatten()
                    ) - set(content.index.astype(str))
            ),
            "node_type": "Unknown"
        })
    ]).reset_index(drop=True)
    # Create the edge list
    edge_list = pd.concat([
        cities,
        pd.DataFrame({
            "subject": content.index[node_indices].astype(str),
            "object": words[word_indices],
            "edge_type": "Paper2Word"
        })
    ]).reset_index(drop=True)
    # Storing the generated node list
    node_list.to_csv(node_path, sep="\t", index=False)
    # Storing the generated edge list
    edge_list.to_csv(edge_path, sep="\t", index=False)


import os
import shutil
from typing import Callable, Dict, List, Optional

import compress_json
from downloaders import BaseDownloader
from environments_utils import is_windows
from userinput.utils import set_validator, closest
from ..ensmallen import Graph, edge_list_utils
from .get_dataset import validate_graph_version


class AutomaticallyRetrievedGraph:
    def __init__(
        self,
        graph_name: str,
        version: str,
        repository: str,
        directed: bool = False,
        preprocess: bool = True,
        load_nodes: bool = True,
        verbose: int = 2,
        cache: bool = True,
        cache_path: str = "graphs",
        callbacks: List[Callable] = (),
        callbacks_arguments: List[Dict] = (),
        additional_graph_kwargs: Dict = None
    ):
        """Create new automatically retrieved graph.

        Parameters
        -------------------
        graph_name: str,
            The name of the graph to be retrieved and loaded.
        version: str,
            The version of the graph to be retrieved.
        repository: str,
            Name of the repository to load data from.
        directed: bool = False,
            Whether to load the graph as directed or undirected.
            By default false.
        preprocess: bool = True,
            Whether to preprocess the node list and edge list
            to be loaded optimally in both time and memory.
        load_nodes: bool = True,
            Whether to load the nodes vocabulary or treat the nodes
            simply as a numeric range.
        verbose: int = 2,
            Whether to show loading bars.
        cache: bool = True,
            Whether to use cache, i.e. download files only once
            and preprocess them only once.
        cache_path: str = "graphs",
            Where to store the downloaded graphs.
        callbacks: List[Callable] = (),
            Eventual callbacks to call after download files.
        callbacks_arguments: List[Dict] = (),
            Eventual arguments for callbacks.
        additional_graph_kwargs: Dict = None,
            Eventual additional kwargs for loading the graph.

        Raises
        -------------------
        ValueError,
            If the given graph name is not available.
        ValueError,
            If the preprocess flag is provided but the system
            is Windows, which does not provide the sort command.
        """
        try:

            validate_graph_version(graph_name, repository, version)

            all_versions = compress_json.local_load(os.path.join(
                repository,
                "{}.json.gz".format(graph_name)
            ))

            self._graph = all_versions[version]
        except FileNotFoundError:
            raise ValueError(
                (
                    "Requested graph `{}` is not currently available.\n"
                    "Open an issue on the Graph repository to ask "
                    "for this graph to be added."
                ).format(graph_name)
            )

        if preprocess and is_windows():
            raise ValueError(
                "Currently preprocessing to optimal edge list is not supported "
                "on Windows because the sorting step is based upon the `sort` "
                "command, which is only available to our knowledge on Linux and "
                "macOS systems."
            )
        self._directed = directed
        self._preprocess = preprocess
        self._load_nodes = load_nodes
        self._name = graph_name
        self._version = version
        self._cache = cache
        self._verbose = verbose
        self._callbacks = callbacks
        if additional_graph_kwargs is None:
            additional_graph_kwargs = {}
        self._additional_graph_kwargs = additional_graph_kwargs
        self._callbacks_arguments = callbacks_arguments
        self._cache_path = os.path.join(cache_path, graph_name, version)
        self._downloader = BaseDownloader(
            auto_extract=True,
            cache=cache,
            target_directory=self._cache_path,
            verbose=self._verbose,
            process_number=1
        )

    def get_preprocessed_graph_directory_path(self) -> str:
        """Return the path to the directory where to store the preprocessed graph."""
        return os.path.join(
            self._cache_path,
            "preprocessed",
            "directed" if self._directed else "undirected"
        )

    def get_preprocessed_graph_node_types_path(self) -> str:
        """Return the path to file where the metadata of the graph are stored."""
        return os.path.join(
            self.get_preprocessed_graph_directory_path(),
            "node_types.tsv"
        )

    def get_preprocessed_graph_nodes_path(self) -> str:
        """Return the path to file where the metadata of the graph are stored."""
        return os.path.join(
            self.get_preprocessed_graph_directory_path(),
            "nodes.tsv"
        )

    def get_preprocessed_graph_edge_types_path(self) -> str:
        """Return the path to file where the metadata of the graph are stored."""
        return os.path.join(
            self.get_preprocessed_graph_directory_path(),
            "edge_types.tsv"
        )

    def get_preprocessed_graph_edges_path(self) -> str:
        """Return the path to file where the metadata of the graph are stored."""
        return os.path.join(
            self.get_preprocessed_graph_directory_path(),
            "edges.tsv"
        )

    def get_preprocessed_graph_metadata_path(self) -> str:
        """Return the path to file where the metadata of the graph are stored."""
        return os.path.join(
            self.get_preprocessed_graph_directory_path(),
            "metadata.json"
        )

    def is_preprocessed(self) -> bool:
        """Return whether this graph was preprocessed."""
        return os.path.exists(
            self.get_preprocessed_graph_metadata_path()
        )

    def store_preprocessed_metadata(
        self,
        node_types_number: Optional[int],
        nodes_number: int,
        edge_types_number: Optional[int],
        edges_number: int,
    ):
        """Store the provided metadata.

        Parameters
        --------------------------------
        node_types_number: Optional[int],
            The number of unique node types existing in this graph.
        nodes_number: int,
            The number of unique nodes existing in this graph.
        edge_types_number: Optional[int],
            The number of unique edge types existing in this graph.
        edges_number: int,
            The number of edges existing in this graph.
        """
        compress_json.dump(
            dict(
                node_types_number=node_types_number,
                nodes_number=nodes_number,
                edge_types_number=edge_types_number,
                edges_number=edges_number
            ),
            self.get_preprocessed_graph_metadata_path()
        )

    def get_preprocessed_metadata(self) -> Dict:
        """Return the stored metadata.

        Returns
        --------------------------------
        Dictionary with the metadata.
        """
        return compress_json.load(
            self.get_preprocessed_graph_metadata_path()
        )

    def __call__(self) -> Graph:
        """Return Graph containing required graph."""
        paths = self._graph.get("paths", None)
        graph_arguments = {
            **self._graph["arguments"],
            **self._additional_graph_kwargs
        }
        if paths is not None:
            paths = [
                os.path.join(self._cache_path, path)
                for path in paths
            ]

        root = self.get_preprocessed_graph_directory_path()

        if not self._cache and os.path.exists(root):
            shutil.rmtree(root)

        if not os.path.exists(root):
            # Download the necessary data
            self._downloader.download(
                self._graph["urls"],
                paths
            )

        os.makedirs(
            root,
            exist_ok=True
        )

        # Call the provided callbacks to process the edge lists, if any.
        for callback, arguments in zip(self._callbacks, self._callbacks_arguments):
            callback(**{
                key: os.path.join(self._cache_path, value)
                if key.endswith("_path") else value
                for key, value in arguments.items()
            })

        # Preprocess the edge list to an optimal edge list
        # if this is enabled.
        if self._preprocess:
            # If any of the node types columns have been provided,
            # we compute the target node types column
            target_node_type_list_path = None
            if any(
                graph_arguments.get(column) is not None
                for column in (
                    "node_list_node_types_column_number",
                    "node_list_node_types_column",
                )
            ):
                target_node_type_list_path = self.get_preprocessed_graph_node_types_path()

            # If any of the edge types columns have been provided,
            # we compute the target edge types column
            target_edge_type_list_path = None
            if any(
                graph_arguments.get(column) is not None
                for column in (
                    "edge_list_edge_types_column_number",
                    "edge_list_edge_types_column",
                )
            ):
                target_edge_type_list_path = self.get_preprocessed_graph_edge_types_path()

            target_node_path = self.get_preprocessed_graph_nodes_path()
            target_edge_path = self.get_preprocessed_graph_edges_path()

            # If a node path was specified
            node_path = graph_arguments.get(
                "node_path"
            )

            # And it is not None
            if node_path is not None:
                # We add the cache path to it
                node_path = os.path.join(
                    self._cache_path,
                    graph_arguments["node_path"]
                )

            may_have_singletons = graph_arguments.get(
                "may_have_singletons", True
            ) and node_path is not None

            if not self.is_preprocessed():
                (
                    node_types_number,
                    nodes_number,
                    edge_types_number,
                    edges_number
                ) = edge_list_utils.build_optimal_lists_files(
                    # original_node_type_path,
                    # original_node_type_list_separator,
                    # original_node_types_column_number,
                    # original_node_types_column,
                    # original_numeric_node_type_ids,
                    # original_minimum_node_type_id,
                    # original_node_type_list_header,
                    # original_node_type_list_rows_to_skip,
                    # original_node_type_list_max_rows_number,
                    # original_node_type_list_comment_symbol,
                    # original_load_node_type_list_in_parallel,
                    # original_node_type_list_is_correct,
                    # node_types_number,
                    target_node_type_list_path=target_node_type_list_path,
                    target_node_type_list_separator="\t",
                    target_node_type_list_node_types_column_number=0,
                    original_node_path=node_path,
                    original_node_list_header=graph_arguments.get(
                        "node_list_header"
                    ),
                    node_list_rows_to_skip=graph_arguments.get(
                        "node_list_rows_to_skip"
                    ),
                    node_list_is_correct=graph_arguments.get(
                        "node_list_is_correct"
                    ),
                    node_list_max_rows_number=graph_arguments.get(
                        "node_list_max_rows_number"
                    ),
                    node_list_comment_symbol=graph_arguments.get(
                        "node_list_comment_symbol"
                    ),
                    default_node_type=graph_arguments.get(
                        "default_node_type"
                    ),
                    original_nodes_column_number=graph_arguments.get(
                        "nodes_column_number"
                    ),
                    original_nodes_column=graph_arguments.get(
                        "nodes_column"
                    ),
                    original_node_types_separator=graph_arguments.get(
                        "node_types_separator"
                    ),
                    original_node_list_separator=graph_arguments.get(
                        "node_list_separator"
                    ),
                    original_node_list_node_types_column_number=graph_arguments.get(
                        "node_list_node_types_column_number"
                    ),
                    original_node_list_node_types_column=graph_arguments.get(
                        "node_list_node_types_column"
                    ),
                    nodes_number=graph_arguments.get("nodes_number"),
                    # original_minimum_node_id,
                    # original_numeric_node_ids,
                    # original_node_list_numeric_node_type_ids,
                    original_skip_node_types_if_unavailable=True,
                    # It make sense to load the node list in parallel only when
                    # you have to preprocess the node types, since otherwise the nodes number
                    # would be unknown.
                    original_load_node_list_in_parallel=target_node_type_list_path is not None,
                    maximum_node_id=graph_arguments.get(
                        "maximum_node_id"
                    ),
                    target_node_path=target_node_path,
                    target_node_list_separator="\t",
                    target_nodes_column=graph_arguments.get(
                        "nodes_column"
                    ),
                    target_nodes_column_number=0,
                    target_node_list_node_types_column_number=1,
                    target_node_types_separator="|",
                    # original_edge_type_path,
                    # original_edge_type_list_separator,
                    # original_edge_types_column_number,
                    # original_edge_types_column,
                    # original_numeric_edge_type_ids,
                    # original_minimum_edge_type_id,
                    # original_edge_type_list_header,
                    # edge_type_list_rows_to_skip,
                    # edge_type_list_max_rows_number,
                    # edge_type_list_comment_symbol,
                    # load_edge_type_list_in_parallel=True,
                    # edge_type_list_is_correct,
                    # edge_types_number,
                    target_edge_type_list_path=target_edge_type_list_path,
                    target_edge_type_list_separator="\t",
                    target_edge_type_list_edge_types_column_number=0,
                    original_edge_path=os.path.join(
                        self._cache_path, graph_arguments["edge_path"]),
                    original_edge_list_header=graph_arguments.get(
                        "edge_list_header"
                    ),
                    original_edge_list_separator=graph_arguments.get(
                        "edge_list_separator"
                    ),
                    original_sources_column_number=graph_arguments.get(
                        "sources_column_number"
                    ),
                    original_sources_column=graph_arguments.get(
                        "sources_column"
                    ),
                    original_destinations_column_number=graph_arguments.get(
                        "destinations_column_number"
                    ),
                    original_destinations_column=graph_arguments.get(
                        "destinations_column"
                    ),
                    original_edge_list_edge_types_column_number=graph_arguments.get(
                        "edge_list_edge_types_column_number"
                    ),
                    original_edge_list_edge_types_column=graph_arguments.get(
                        "edge_list_edge_types_column"
                    ),
                    default_edge_type=graph_arguments.get(
                        "default_edge_type"
                    ),
                    original_weights_column_number=graph_arguments.get(
                        "weights_column_number"
                    ),
                    original_weights_column=graph_arguments.get(
                        "weights_column"
                    ),
                    default_weight=graph_arguments.get(
                        "default_weight"
                    ),
                    original_edge_list_numeric_node_ids=graph_arguments.get(
                        "edge_list_numeric_node_ids"
                    ),
                    skip_weights_if_unavailable=graph_arguments.get(
                        "skip_weights_if_unavailable"
                    ),
                    skip_edge_types_if_unavailable=graph_arguments.get(
                        "skip_edge_types_if_unavailable"
                    ),
                    edge_list_comment_symbol=graph_arguments.get(
                        "edge_list_comment_symbol"
                    ),
                    edge_list_max_rows_number=graph_arguments.get(
                        "edge_list_max_rows_number"
                    ),
                    edge_list_rows_to_skip=graph_arguments.get(
                        "edge_list_rows_to_skip"
                    ),
                    load_edge_list_in_parallel=True,
                    edges_number=graph_arguments.get("edges_number"),
                    target_edge_path=target_edge_path,
                    target_edge_list_separator="\t",
                    directed=self._directed,
                    verbose=self._verbose > 0,
                    name=self._name,
                )
                # Store the obtained metadata
                self.store_preprocessed_metadata(
                    node_types_number,
                    nodes_number,
                    edge_types_number,
                    edges_number
                )
            # Load the stored metadata
            metadata = self.get_preprocessed_metadata()
            # If the node types are provided
            has_node_types = metadata["node_types_number"] is not None
            if has_node_types:
                node_types_arguments = {
                    "node_type_path": target_node_type_list_path,
                    "node_types_column_number": 0,
                    "node_type_list_is_correct": True,
                    "node_type_list_separator": "\t"
                }
            else:
                node_types_arguments = {}
            # If the nodes are to be loaded
            if self._load_nodes:
                nodes_arguments = {
                    "node_path": target_node_path,
                    "node_list_separator": "\t",
                    "nodes_column_number": 0,
                    "node_types_separator": "|" if has_node_types else None,
                    "node_list_node_types_column_number": 1 if has_node_types else None,
                    "node_list_numeric_node_type_ids": True if has_node_types else None,
                    "skip_node_types_if_unavailable": True if has_node_types else None,
                    "node_list_is_correct": True,
                    **node_types_arguments
                }
            else:
                nodes_arguments = {
                    "numeric_node_ids": True,
                }
                
            # If the edge types are provided
            has_edge_types = metadata["edge_types_number"] is not None
            if has_edge_types:
                edge_types_arguments = {
                    "edge_type_path": target_edge_type_list_path,
                    "edge_types_column_number": 0,
                    "edge_type_list_is_correct": True,
                    "edge_type_list_separator": "\t"
                }
            else:
                edge_types_arguments = {}
            # Load the graph
            return Graph.from_csv(**{
                **metadata,
                **nodes_arguments,
                **edge_types_arguments,

                "edge_path": target_edge_path,
                "edge_list_header": False,
                "sources_column_number": 0,
                "destinations_column_number": 1,
                "edge_list_edge_types_column_number": None if metadata["edge_types_number"] is None else 2,
                "weights_column_number": 2 + int(metadata["edge_types_number"] is not None),
                "edge_list_numeric_edge_type_ids": True,
                "edge_list_numeric_node_ids": True,
                "skip_weights_if_unavailable": True,
                "skip_edge_types_if_unavailable": True,
                "edge_list_is_complete": True,
                "edge_list_may_contain_duplicates": False,
                "edge_list_is_sorted": True,
                "edge_list_is_correct": True,
                "edges_number": metadata["edges_number"],
                "nodes_number": metadata["nodes_number"],
                "may_have_singletons": may_have_singletons,
                "verbose": self._verbose > 0,
                "directed": self._directed,
                "name": self._name,
            })

        # Otherwise just load the graph.
        return Graph.from_csv(**{
            **{
                key: os.path.join(self._cache_path, value)
                if key.endswith("_path") else value
                for key, value in graph_arguments.items()
            },
            "directed": self._directed,
            "verbose": self._verbose > 0,
            "name": self._name,
            **self._additional_graph_kwargs,
        })
